@@ -1,5 +1,5 @@
-// Copyright 2022 The envd Authors
-// Copyright 2022 The okteto remote Authors
+// Copyright 2023 The envd Authors
+// Copyright 2023 The okteto remote Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -21,9 +21,10 @@ import (
 	"os"
 
 	"github.com/cockroachdb/errors"
-	rawssh "github.com/gliderlabs/ssh"
+	"github.com/gliderlabs/ssh"
 	"github.com/sirupsen/logrus"
 	"github.com/urfave/cli/v2"
+	rawssh "golang.org/x/crypto/ssh"
 
 	"github.com/tensorchord/envd/pkg/config"
 	"github.com/tensorchord/envd/pkg/remote/sshd"
@@ -36,6 +37,7 @@ const (
 	flagNoAuth  = "no-auth"
 	flagPort    = "port"
 	flagShell   = "shell"
+	flagHostKey = "hostkey"
 )
 
 func main() {
@@ -56,16 +58,23 @@ func main() {
 			Name:    flagAuthKey,
 			Usage:   "path to authorized keys file, defaults to " + config.ContainerAuthorizedKeysPath,
 			Value:   config.ContainerAuthorizedKeysPath,
+			EnvVars: []string{"ENVD_AUTHORIZED_KEYS_PATH"},
 			Aliases: []string{"a"},
 		},
+		&cli.StringFlag{
+			Name:    flagHostKey,
+			Usage:   "path to the host key",
+			EnvVars: []string{"ENVD_HOST_KEY"},
+		},
 		&cli.BoolFlag{
 			Name:  flagNoAuth,
 			Usage: "disable authentication",
 			Value: false,
 		},
 		&cli.IntFlag{
-			Name:  flagPort,
-			Usage: "port to listen on",
+			Name:    flagPort,
+			Usage:   "port to listen on",
+			Aliases: []string{"p"},
 		},
 		&cli.StringFlag{
 			Name:  flagShell,
@@ -94,19 +103,20 @@ func main() {
 func sshServer(c *cli.Context) error {
 	err := sshd.GetShell(c.String(flagShell))
 	if err != nil {
-		logrus.Fatal(err.Error())
+		logrus.WithError(err).Fatal()
 	}
 	shell := c.String(flagShell)
 
 	port := c.Int(flagPort)
 	if port == 0 {
 		return errors.New("port must be set")
-	} else if port <= 1024 {
+	}
+	if port <= 1024 {
 		return errors.New("failed to parse port: port is reserved")
 	}
 
 	noAuth := c.Bool(flagNoAuth)
-	var keys []rawssh.PublicKey
+	var keys []ssh.PublicKey
 	if !noAuth {
 		var err error
 		path := c.String(flagAuthKey)
@@ -124,10 +134,27 @@ func sshServer(c *cli.Context) error {
 		logrus.Warn("no authentication enabled")
 	}
 
+	var hostKey ssh.Signer = nil
+	if c.String(flagHostKey) != "" {
+		// read private key file
+		pemBytes, err := os.ReadFile(c.String(flagHostKey))
+		if err != nil {
+			return errors.Wrapf(
+				err, "reading private key %s failed", c.String(flagHostKey))
+		}
+		privateKey, err := rawssh.ParsePrivateKey(pemBytes)
+		if err != nil {
+			return err
+		}
+		logrus.Debugf("load host key from %s", c.String(flagHostKey))
+		hostKey = privateKey
+	}
+
 	srv := sshd.Server{
 		Port:           port,
 		Shell:          shell,
 		AuthorizedKeys: keys,
+		Hostkey:        hostKey,
 	}
 
 	logrus.Infof("ssh server %s started in 0.0.0.0:%d", version.GetVersion().String(), srv.Port)
