@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -21,6 +21,7 @@ import (
 	"github.com/cockroachdb/errors"
 	"github.com/spf13/viper"
 	"github.com/urfave/cli/v2"
+	"go.starlark.net/resolve"
 	"go.starlark.net/starlark"
 	"go.starlark.net/syntax"
 
@@ -44,18 +45,20 @@ func handleErr(err error) {
 	}
 
 	if viper.GetBool(flag.FlagDebug) {
-		fmt.Fprintf(os.Stderr, "error: %v\n", err)
+		fmt.Fprintf(os.Stderr, "error: %+v\n", err)
 	}
 
-	rootCause := errors.Cause(err)
 	var evalErr *starlark.EvalError
 	var syntaxErr *syntax.Error
+	var resolveErr resolve.ErrorList
 	if ok := errors.As(err, &evalErr); ok {
 		fmt.Fprintln(os.Stderr, evalErr.Backtrace())
 	} else if ok := errors.As(err, &syntaxErr); ok {
 		fmt.Fprintln(os.Stderr, syntaxErr)
+	} else if ok := errors.As(err, &resolveErr); ok {
+		fmt.Fprintf(os.Stderr, "%+v\n", resolveErr)
 	} else {
-		fmt.Fprintf(os.Stderr, "error: %v\n", rootCause)
+		fmt.Fprintf(os.Stderr, "error: %v\n", errors.Cause(err))
 	}
 	os.Exit(1)
 }
