@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -18,7 +18,6 @@ import (
 	"github.com/cockroachdb/errors"
 	_ "github.com/moby/buildkit/client/connhelper/dockercontainer"
 	_ "github.com/moby/buildkit/client/connhelper/kubepod"
-	_ "github.com/moby/buildkit/client/connhelper/nerdctlcontainer"
 	_ "github.com/moby/buildkit/client/connhelper/podmancontainer"
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/viper"
@@ -62,7 +61,7 @@ func New() EnvdApp {
 		&cli.StringFlag{
 			Name:   flag.FlagBuildkitdImage,
 			Usage:  "docker image to use for buildkitd",
-			Value:  "docker.io/moby/buildkit:v0.10.3",
+			Value:  "docker.io/moby/buildkit:v0.10.6",
 			Hidden: true,
 		},
 		&cli.StringFlag{
@@ -99,6 +98,7 @@ func New() EnvdApp {
 		CommandDebug,
 		CommandVersion,
 		CommandTop,
+		CommandReference,
 	}
 
 	internalApp.CustomAppHelpTemplate = ` envd - Development environment for data science and AI/ML teams
@@ -156,6 +156,15 @@ func New() EnvdApp {
 		return nil
 	}
 
+	internalApp.ExitErrHandler = func(context *cli.Context, err error) {
+		if err != nil {
+			logrus.WithFields(logrus.Fields{
+				"app":     "envd",
+				"version": internalApp.Version,
+			}).WithError(err).Fatal("exit")
+		}
+	}
+
 	return EnvdApp{
 		App: *internalApp,
 	}
