@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -35,14 +35,23 @@ var CommandContextCreate = &cli.Command{
 		},
 		&cli.StringFlag{
 			Name:  "builder",
-			Usage: "Builder to use (docker-container, kube-pod, tcp)",
+			Usage: "Builder to use (docker-container, kube-pod, tcp, unix, moby-worker, nerdctl-container)",
 			Value: string(types.BuilderTypeDocker),
 		},
 		&cli.StringFlag{
-			Name:  "builder-socket",
-			Usage: "Builder socket",
+			Name:  "builder-address",
+			Usage: "Builder address",
 			Value: "envd_buildkitd",
 		},
+		&cli.StringFlag{
+			Name:  "runner",
+			Usage: "Runner to use(docker, envd-server)",
+			Value: string(types.RunnerTypeDocker),
+		},
+		&cli.StringFlag{
+			Name:  "runner-address",
+			Usage: "Runner address",
+		},
 		&cli.BoolFlag{
 			Name:  "use",
 			Usage: "Use the context",
@@ -54,17 +63,38 @@ var CommandContextCreate = &cli.Command{
 func contextCreate(clicontext *cli.Context) error {
 	name := clicontext.String("name")
 	builder := clicontext.String("builder")
-	builderSocket := clicontext.String("builder-socket")
+	builderAddress := clicontext.String("builder-address")
+	runner := clicontext.String("runner")
+	runnerAddress := clicontext.String("runner-address")
 	use := clicontext.Bool("use")
 
-	err := home.GetManager().ContextCreate(name,
-		types.BuilderType(builder), builderSocket, use)
+	logger := logrus.WithFields(logrus.Fields{
+		"cmd":            "context create",
+		"name":           name,
+		"builder":        builder,
+		"builderAddress": builderAddress,
+		"runner":         runner,
+		"runnerAddress":  runnerAddress,
+		"use":            use,
+	})
+
+	c := types.Context{
+		Name:           name,
+		Builder:        types.BuilderType(builder),
+		BuilderAddress: builderAddress,
+		Runner:         types.RunnerType(runner),
+	}
+	if runnerAddress != "" {
+		c.RunnerAddress = &runnerAddress
+	}
+
+	err := home.GetManager().ContextCreate(c, use)
 	if err != nil {
 		return errors.Wrap(err, "failed to create context")
 	}
-	logrus.Infof("Context %s is created", name)
+	logger.Infof("Context %s is created", name)
 	if use {
-		logrus.Infof("Current context is now \"%s\"", name)
+		logger.Infof(`Current context is "%s"`, name)
 	}
 	return nil
 }
