@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -43,6 +43,7 @@ func contextRemove(clicontext *cli.Context) error {
 	if err != nil {
 		return errors.Wrap(err, "failed to remove context")
 	}
-	logrus.Infof("Context %s is removed", name)
+	logrus.WithField("cmd", "context remove").
+		Infof("Context %s is removed", name)
 	return nil
 }
