@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -43,6 +43,7 @@ func contextUse(clicontext *cli.Context) error {
 	if err != nil {
 		return errors.Wrapf(err, "failed to use the specified context %s", name)
 	}
-	logrus.Infof("Current context is now \"%s\"", name)
+	logrus.WithField("cmd", "context use").
+		Infof(`Current context is "%s"`, name)
 	return nil
 }
