@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -111,12 +111,19 @@ func exec(clicontext *cli.Context) error {
 			return errors.Wrapf(err, "failed to get environment: %s", name)
 		}
 
-		logrus.Debugf("runtime commands: %s", rg.RuntimeCommands)
-		if cmd, ok := rg.RuntimeCommands[command]; !ok {
+		logrus.WithFields(logrus.Fields{
+			"cmd":        "exec",
+			"name":       name,
+			"command":    command,
+			"rawCommand": rawCommand,
+			"path":       path,
+		}).Debugf("runtime commands: %s", rg.RuntimeCommands)
+
+		cmd, ok := rg.RuntimeCommands[command]
+		if !ok {
 			return errors.Newf("command %s does not exist", command)
-		} else {
-			resultCommand = cmd
 		}
+		resultCommand = cmd
 	}
 
 	opt, err := ssh.GetOptions(name)
@@ -128,12 +135,12 @@ func exec(clicontext *cli.Context) error {
 	if err != nil {
 		return errors.Wrap(err, "failed to get the ssh client")
 	}
-	if bytes, err := sshClient.ExecWithOutput(resultCommand); err != nil {
+	bytes, err := sshClient.ExecWithOutput(resultCommand)
+	if err != nil {
 		fmt.Fprintln(clicontext.App.Writer, string(bytes))
 		return errors.Wrapf(err,
 			"failed to execute the command `%s`", resultCommand)
-	} else {
-		fmt.Fprint(clicontext.App.Writer, string(bytes))
 	}
+	fmt.Fprint(clicontext.App.Writer, string(bytes))
 	return nil
 }
