@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -116,13 +116,22 @@ func isCondaEnvFile(file string) bool {
 }
 
 func initCommand(clicontext *cli.Context) error {
-	lang := strings.ToLower(clicontext.String("lang"))
 	buildContext, err := filepath.Abs(clicontext.Path("path"))
 	force := clicontext.Bool("force")
 	if err != nil {
 		return err
 	}
 
+	filePath := filepath.Join(buildContext, "build.envd")
+	exists, err := fileutil.FileExists(filePath)
+	if err != nil {
+		return err
+	}
+	if exists && !force {
+		return errors.Errorf("build.envd already exists, use --force to overwrite it.\nOr you can run the command `envd up` to set up a new environment.")
+	}
+
+	lang := strings.ToLower(clicontext.String("lang"))
 	if !isValidLang(lang) {
 		startQuestion(LanguageChoice)
 		if len(selectionMap[LabelLanguage]) > 0 {
@@ -139,15 +148,6 @@ func initCommand(clicontext *cli.Context) error {
 			"init", telemetry.AddField("duration", time.Since(start).Seconds()))
 	}(time.Now())
 
-	filePath := filepath.Join(buildContext, "build.envd")
-	exists, err := fileutil.FileExists(filePath)
-	if err != nil {
-		return err
-	}
-	if exists && !force {
-		return errors.Errorf("build.envd already exists, use --force to overwrite it")
-	}
-
 	if lang == "python" {
 		err = InitPythonEnv(buildContext)
 		if err != nil {
