@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@ package app
 
 import (
 	"fmt"
+	"path/filepath"
 	"strings"
 	"time"
 
@@ -30,7 +31,9 @@ import (
 	"github.com/tensorchord/envd/pkg/home"
 	"github.com/tensorchord/envd/pkg/ssh"
 	sshconfig "github.com/tensorchord/envd/pkg/ssh/config"
+	"github.com/tensorchord/envd/pkg/syncthing"
 	"github.com/tensorchord/envd/pkg/types"
+	"github.com/tensorchord/envd/pkg/util/fileutil"
 	"github.com/tensorchord/envd/pkg/util/netutil"
 )
 
@@ -69,9 +72,15 @@ var CommandCreate = &cli.Command{
 			Value:   sshconfig.GetPrivateKeyOrPanic(),
 			Hidden:  true,
 		},
+		&cli.PathFlag{
+			Name:    "path",
+			Usage:   "Working directory path to be used as project root",
+			Aliases: []string{"p"},
+			Value:   ".",
+		},
 		&cli.StringFlag{
 			Name:  "host",
-			Usage: "Assign the host address for environment ssh acesss server listening",
+			Usage: "Assign the host address for the environment SSH access server listening",
 			Value: envd.Localhost,
 		},
 		&cli.IntFlag{
@@ -80,7 +89,7 @@ var CommandCreate = &cli.Command{
 			Value: 2048,
 		},
 		&cli.StringFlag{
-			Name:  "cpu",
+			Name:  "cpus",
 			Usage: "Request CPU resources (number of cores), such as 0.5, 1, 2",
 			Value: "",
 		},
@@ -94,6 +103,16 @@ var CommandCreate = &cli.Command{
 			Usage: "Request GPU resources (number of gpus), such as 1, 2",
 			Value: "",
 		},
+		&cli.BoolFlag{
+			Name:  "sync",
+			Usage: "Sync the local directory with the remote container",
+			Value: false,
+		},
+		&cli.StringSliceFlag{
+			Name:    "volume",
+			Usage:   "Mount host directory into container",
+			Aliases: []string{"v"},
+		},
 	},
 	Action: run,
 }
@@ -103,9 +122,6 @@ func run(clicontext *cli.Context) error {
 	if err != nil {
 		return errors.Wrap(err, "failed to get current context")
 	}
-	if c.Runner == types.RunnerTypeDocker {
-		return errors.Newf("docker runner is not supported for this command, please use `envd up`")
-	}
 	telemetry.GetReporter().Telemetry(
 		"run", telemetry.AddField("runner", c.Runner))
 
@@ -125,22 +141,44 @@ func run(clicontext *cli.Context) error {
 		Image:           clicontext.String("image"),
 		Timeout:         clicontext.Duration("timeout"),
 		NumMem:          clicontext.String("memory"),
-		NumCPU:          clicontext.String("cpu"),
+		NumCPU:          clicontext.String("cpus"),
 		NumGPU:          clicontext.Int("gpu"),
 		ShmSize:         clicontext.Int("shm-size"),
 		EnvironmentName: name,
 	}
 	if c.Runner == types.RunnerTypeEnvdServer {
-		opt.EnvdServerSource = &envd.EnvdServerSource{}
+		opt.EnvdServerSource = &envd.EnvdServerSource{
+			Sync: clicontext.Bool("sync"),
+		}
+		if len(clicontext.StringSlice("volume")) > 0 {
+			return errors.New("volume is not supported for envd-server runner")
+		}
+	} else if c.Runner == types.RunnerTypeDocker {
+		opt.DockerSource = &envd.DockerSource{
+			MountOptions: clicontext.StringSlice("volume"),
+		}
+
+		buildContext, err := filepath.Abs(clicontext.Path("path"))
+		if err != nil {
+			return errors.Wrap(err, "failed to get absolute path of the build context")
+		}
+		opt.BuildContext = buildContext
 	}
+
 	res, err := engine.StartEnvd(clicontext.Context, opt)
 	if err != nil {
 		return err
 	}
 
-	logrus.Debugf("container %s is running", res.Name)
+	logger := logrus.WithFields(logrus.Fields{
+		"cmd":          "run",
+		"StartOptions": opt,
+		"StartResult":  res,
+	})
 
-	logrus.Debugf("add entry %s to SSH config.", res.Name)
+	logger.Debugf("container %s is running", res.Name)
+
+	logger.Debugf("add entry %s to SSH config.", res.Name)
 	hostname, err := c.GetSSHHostname(opt.SshdHost)
 	if err != nil {
 		return errors.Wrap(err, "failed to get the ssh hostname")
@@ -154,6 +192,7 @@ func run(clicontext *cli.Context) error {
 	if err != nil {
 		return errors.Wrap(err, "failed to get the username")
 	}
+
 	eo := sshconfig.EntryOptions{
 		Name:               res.Name,
 		IFace:              hostname,
@@ -164,7 +203,8 @@ func run(clicontext *cli.Context) error {
 		User:               username,
 	}
 	if err = sshconfig.AddEntry(eo); err != nil {
-		logrus.Infof("failed to add entry %s to your SSH config file: %s", res.Name, err)
+		logger.WithError(err).
+			Infof("failed to add entry %s to your SSH config file", res.Name)
 		return errors.Wrap(err, "failed to add entry to your SSH config file")
 	}
 
@@ -197,7 +237,7 @@ func run(clicontext *cli.Context) error {
 			}
 			localAddress := fmt.Sprintf("%s:%d", "localhost", localPort)
 			remoteAddress := fmt.Sprintf("%s:%d", "localhost", p.Port)
-			logrus.Infof("service \"%s\" is listening at %s\n", p.Name, localAddress)
+			logger.Infof(`service "%s" is listening at %s\n`, p.Name, localAddress)
 			go func() {
 				if err := sshClient.LocalForward(localAddress, remoteAddress); err != nil {
 					outputChannel <- errors.Wrap(err, "failed to forward to local port")
@@ -205,6 +245,35 @@ func run(clicontext *cli.Context) error {
 			}()
 		}
 
+		if clicontext.Bool("sync") {
+			go func() {
+				if err := sshClient.LocalForward(syncthing.DefaultRemoteAPIAddress, syncthing.DefaultRemoteAPIAddress); err != nil {
+					outputChannel <- errors.Wrap(err, "failed to forward to remote api port")
+				}
+			}()
+
+			go func() {
+				syncthingRemoteAddr := fmt.Sprintf("127.0.0.1:%s", syncthing.ParsePortFromAddress(syncthing.DefaultRemoteDeviceAddress))
+				if err := sshClient.LocalForward(syncthingRemoteAddr, syncthingRemoteAddr); err != nil {
+					outputChannel <- errors.Wrap(err, "failed to forward to remote port")
+				}
+			}()
+
+			go func() {
+				syncthingLocalAddr := fmt.Sprintf("127.0.0.1:%s", syncthing.ParsePortFromAddress(syncthing.DefaultLocalDeviceAddress))
+				if err := sshClient.RemoteForward(syncthingLocalAddr, syncthingLocalAddr); err != nil {
+					outputChannel <- errors.Wrap(err, "failed to forward to local port")
+				}
+			}()
+
+			localSyncthing, _, err := startSyncthing(res.Name)
+			if err != nil {
+				return errors.Wrap(err, "failed to start syncthing")
+			}
+			defer localSyncthing.StopLocalSyncthing()
+
+		}
+
 		go func() {
 			// TODO(gaocegege): Avoid the hard code.
 			if err := sshClient.Attach(); err != nil {
@@ -219,3 +288,40 @@ func run(clicontext *cli.Context) error {
 	}
 	return nil
 }
+
+func startSyncthing(name string) (*syncthing.Syncthing, *syncthing.Syncthing, error) {
+	cwd, err := fileutil.CWD()
+	if err != nil {
+		return nil, nil, errors.Wrap(err, "failed to get current working directory")
+	}
+	projectName := filepath.Base(cwd)
+
+	logger := logrus.WithFields(logrus.Fields{
+		"cwd":         cwd,
+		"projectName": projectName,
+	})
+
+	localSyncthing, err := syncthing.InitializeLocalSyncthing(name)
+	if err != nil {
+		return nil, nil, errors.Wrap(err, "failed to initialize local syncthing")
+	}
+
+	remoteSyncthing, err := syncthing.InitializeRemoteSyncthing()
+	if err != nil {
+		return nil, nil, errors.Wrap(err, "failed to initialize remote syncthing")
+	}
+	logger.Debug("Remote syncthing initialized")
+
+	err = syncthing.ConnectDevices(localSyncthing, remoteSyncthing)
+	if err != nil {
+		return nil, nil, errors.Wrap(err, "failed to connect devices")
+	}
+	logger.Debug("Syncthing devices connected")
+
+	err = syncthing.SyncFolder(localSyncthing, remoteSyncthing, cwd, fmt.Sprintf("%s/%s", fileutil.EnvdHomeDir(), projectName))
+	if err != nil {
+		return nil, nil, errors.Wrap(err, "failed to sync folders")
+	}
+
+	return localSyncthing, remoteSyncthing, nil
+}
