@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -29,6 +29,7 @@ import (
 	"github.com/tensorchord/envd/pkg/home"
 	sshconfig "github.com/tensorchord/envd/pkg/ssh/config"
 	"github.com/tensorchord/envd/pkg/types"
+	"github.com/tensorchord/envd/pkg/util/runtimeutil"
 )
 
 var CommandUp = &cli.Command{
@@ -43,6 +44,11 @@ var CommandUp = &cli.Command{
 			Aliases:     []string{"t"},
 			DefaultText: "PROJECT:dev",
 		},
+		&cli.StringFlag{
+			Name:  "name",
+			Usage: "environment name",
+			Value: "",
+		},
 		&cli.PathFlag{
 			Name:    "path",
 			Usage:   "Path to the directory containing the build.envd",
@@ -90,6 +96,21 @@ var CommandUp = &cli.Command{
 			Usage: "Configure the shared memory size (megabyte)",
 			Value: 2048,
 		},
+		&cli.StringFlag{
+			Name:  "cpus",
+			Usage: "Request CPU resources (number of cores), such as 0.5, 1, 2",
+			Value: "",
+		},
+		&cli.StringFlag{
+			Name:  "cpu-set",
+			Usage: "Limit the specific CPUs or cores the environment can use, such as `0-3`, `1,3`",
+			Value: "",
+		},
+		&cli.StringFlag{
+			Name:  "memory",
+			Usage: "Request Memory, such as 512Mb, 2Gb",
+			Value: "",
+		},
 		&cli.BoolFlag{
 			Name:  "detach",
 			Usage: "Detach from the container",
@@ -97,9 +118,14 @@ var CommandUp = &cli.Command{
 		},
 		&cli.BoolFlag{
 			Name:  "no-gpu",
-			Usage: "Launch the CPU container",
+			Usage: "Launch the CPU container even if it's a GPU image",
 			Value: false,
 		},
+		&cli.IntFlag{
+			Name:  "gpus",
+			Usage: "Number of GPUs used in this environment",
+			Value: 0,
+		},
 		&cli.BoolFlag{
 			Name:  "force",
 			Usage: "Force rebuild and run the container although the previous container is running",
@@ -107,20 +133,25 @@ var CommandUp = &cli.Command{
 		},
 		&cli.StringFlag{
 			Name:  "host",
-			Usage: "Assign the host address for environment ssh acesss server listening",
+			Usage: "Assign the host address for the environment SSH access server listening",
 			Value: envd.Localhost,
 		},
 		// https://github.com/urfave/cli/issues/1134#issuecomment-1191407527
 		&cli.StringFlag{
 			Name:    "export-cache",
-			Usage:   "Export the cache (e.g. type=registry,ref=<image>)",
+			Usage:   "Export the cache (e.g. `type=registry,ref=<image>`)",
 			Aliases: []string{"ec"},
 		},
 		&cli.StringFlag{
 			Name:    "import-cache",
-			Usage:   "Import the cache (e.g. type=registry,ref=<image>)",
+			Usage:   "Import the cache (e.g. `type=registry,ref=<image>`)",
 			Aliases: []string{"ic"},
 		},
+		&cli.StringFlag{
+			Name:        "platform",
+			Usage:       "Specify the target platform for the build output, (for example, windows/amd64, linux/amd64, or darwin/arm64)",
+			DefaultText: runtimeutil.GetRuntimePlatform(),
+		},
 	},
 
 	Action: up,
@@ -151,6 +182,7 @@ func up(clicontext *cli.Context) error {
 	ctr := filepath.Base(buildOpt.BuildContextDir)
 	detach := clicontext.Bool("detach")
 	logger := logrus.WithFields(logrus.Fields{
+		"cmd":             "up",
 		"builder-options": buildOpt,
 		"container-name":  ctr,
 		"detach":          detach,
@@ -164,6 +196,9 @@ func up(clicontext *cli.Context) error {
 	if err = buildutil.InterpretEnvdDef(builder); err != nil {
 		return err
 	}
+	if !builder.GetGraph().IsDev() {
+		return errors.New("`envd up` only works for dev images. If you're using v1, please enable dev with `base(dev=True)`.")
+	}
 	if err = buildutil.DetectEnvironment(clicontext, buildOpt); err != nil {
 		return err
 	}
@@ -171,20 +206,26 @@ func up(clicontext *cli.Context) error {
 		return err
 	}
 
-	logrus.Debug("start running the environment")
+	logger.Debug("start running the environment")
 	// Do not attach GPU if the flag is set.
-	gpuEnable := clicontext.Bool("no-gpu")
-	var gpu bool
-	if gpuEnable {
-		gpu = false
+	disableGPU := clicontext.Bool("no-gpu")
+	var defaultGPU bool
+	if disableGPU {
+		defaultGPU = false
 	} else {
-		gpu = builder.GPUEnabled()
+		defaultGPU = builder.GPUEnabled()
 	}
-	numGPU := 0
-	if gpu {
+	numGPU := clicontext.Int("gpus")
+	if defaultGPU && numGPU == 0 {
 		numGPU = 1
 	}
 
+	shmSize := builder.ShmSize()
+	isSetShmSize := clicontext.IsSet("shm-size")
+	if shmSize == 0 || isSetShmSize {
+		shmSize = clicontext.Int("shm-size")
+	}
+
 	opt := envd.Options{
 		Context: c,
 	}
@@ -192,9 +233,12 @@ func up(clicontext *cli.Context) error {
 	if err != nil {
 		return errors.Wrap(err, "failed to create the docker client")
 	}
-	name, err := buildutil.CreateEnvNameFromDir(buildOpt.BuildContextDir)
-	if err != nil {
-		return errors.Wrapf(err, "failed to create the env name from %s", buildOpt.BuildContextDir)
+	name := clicontext.String("name")
+	if name == "" {
+		name, err = buildutil.CreateEnvNameFromDir(buildOpt.BuildContextDir)
+		if err != nil {
+			return errors.Wrapf(err, "failed to create the env name from %s", buildOpt.BuildContextDir)
+		}
 	}
 	startOptions := envd.StartOptions{
 		EnvironmentName: name,
@@ -204,8 +248,15 @@ func up(clicontext *cli.Context) error {
 		Forced:          clicontext.Bool("force"),
 		Timeout:         clicontext.Duration("timeout"),
 		SshdHost:        clicontext.String("host"),
-		ShmSize:         clicontext.Int("shm-size"),
+		ShmSize:         shmSize,
+		NumCPU:          clicontext.String("cpus"),
+		NumMem:          clicontext.String("memory"),
+		CPUSet:          clicontext.String("cpu-set"),
 	}
+	if len(startOptions.NumCPU) > 0 && len(startOptions.CPUSet) > 0 {
+		return errors.New("`--cpus` and `--cpu-set` are mutually exclusive")
+	}
+
 	if c.Runner != types.RunnerTypeEnvdServer {
 		startOptions.EngineSource = envd.EngineSource{
 			DockerSource: &envd.DockerSource{
@@ -221,9 +272,9 @@ func up(clicontext *cli.Context) error {
 	if err != nil {
 		return errors.Wrap(err, "failed to start the envd environment")
 	}
-	logrus.Debugf("container %s is running", res.Name)
+	logger.Debugf("container %s is running", res.Name)
 
-	logrus.Debugf("add entry %s to SSH config.", ctr)
+	logger.Debugf("add entry %s to SSH config.", ctr)
 	hostname, err := c.GetSSHHostname(startOptions.SshdHost)
 	if err != nil {
 		return errors.Wrap(err, "failed to get the ssh hostname")
@@ -235,7 +286,8 @@ func up(clicontext *cli.Context) error {
 		return errors.Wrap(err, "failed to get the ssh entry")
 	}
 	if err = sshconfig.AddEntry(eo); err != nil {
-		logrus.Infof("failed to add entry %s to your SSH config file: %s", ctr, err)
+		logger.WithError(err).
+			Infof("failed to add entry %s to your SSH config file", ctr)
 		return errors.Wrap(err, "failed to add entry to your SSH config file")
 	}
 	telemetry.GetReporter().Telemetry(
