@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -18,7 +18,7 @@ import (
 	"context"
 	"io"
 	"os"
-	"path/filepath"
+	"strings"
 
 	"github.com/cockroachdb/errors"
 	"github.com/docker/cli/cli/config"
@@ -26,6 +26,7 @@ import (
 	"github.com/moby/buildkit/client/llb"
 	"github.com/moby/buildkit/session"
 	"github.com/moby/buildkit/session/auth/authprovider"
+	ocispecs "github.com/opencontainers/image-spec/specs-go/v1"
 	"github.com/sirupsen/logrus"
 	"golang.org/x/sync/errgroup"
 
@@ -37,6 +38,7 @@ import (
 	"github.com/tensorchord/envd/pkg/lang/version"
 	"github.com/tensorchord/envd/pkg/progress/progresswriter"
 	"github.com/tensorchord/envd/pkg/types"
+	"github.com/tensorchord/envd/pkg/util/buildkitutil"
 )
 
 func New(ctx context.Context, opt Options) (Builder, error) {
@@ -45,12 +47,21 @@ func New(ctx context.Context, opt Options) (Builder, error) {
 		return nil, errors.Wrap(err, "failed to parse output")
 	}
 
+	c, err := home.GetManager().ContextGetCurrent()
+	if err != nil {
+		return nil, errors.Wrap(err, "failed to get the current context")
+	}
+
 	logrus.WithField("entry", entries).Debug("getting exporter entry")
 	// Build docker image by default
 	if len(entries) == 0 {
+		exportType := client.ExporterDocker
+		if c.Builder == types.BuilderTypeMoby {
+			exportType = "moby"
+		}
 		entries = []client.ExportEntry{
 			{
-				Type: client.ExporterDocker,
+				Type: exportType,
 			},
 		}
 	} else if len(entries) > 1 {
@@ -76,13 +87,20 @@ func New(ctx context.Context, opt Options) (Builder, error) {
 		GetDepsFilesHandler: vc.GetDefaultGraph().GetDepsFiles,
 	}
 
-	c, err := home.GetManager().ContextGetCurrent()
-	if err != nil {
-		return nil, errors.Wrap(err, "failed to get the current context")
-	}
-	cli, err := buildkitd.NewClient(ctx, c.Builder, c.BuilderAddress, "")
-	if err != nil {
-		return nil, errors.Wrap(err, "failed to create buildkit client")
+	var cli buildkitd.Client
+	bc := buildkitutil.BuildkitConfig{}
+	if c.Builder == types.BuilderTypeMoby {
+		cli, err = buildkitd.NewMobyClient(ctx,
+			c.Builder, c.BuilderAddress, &bc)
+		if err != nil {
+			return nil, errors.Wrap(err, "failed to create moby buildkit client")
+		}
+	} else {
+		cli, err = buildkitd.NewClient(ctx,
+			c.Builder, c.BuilderAddress, &bc)
+		if err != nil {
+			return nil, errors.Wrap(err, "failed to create buildkit client")
+		}
 	}
 	b.Client = cli
 
@@ -103,6 +121,14 @@ func (b generalBuilder) NumGPUs() int {
 	return b.graph.GetNumGPUs()
 }
 
+func (b generalBuilder) ShmSize() int {
+	return b.graph.GetShmSize()
+}
+
+func (b generalBuilder) IsDev() bool {
+	return b.graph.IsDev()
+}
+
 func (b generalBuilder) Build(ctx context.Context, force bool) error {
 	if !force && !b.checkIfNeedBuild(ctx) {
 		return nil
@@ -141,8 +167,11 @@ func (b generalBuilder) Interpret() error {
 }
 
 func (b generalBuilder) Compile(ctx context.Context) (*llb.Definition, error) {
-	envName := filepath.Base(b.BuildContextDir)
-	def, err := b.graph.Compile(ctx, envName, b.PubKeyPath)
+	platform, err := parsePlatform(b.Platform)
+	if err != nil {
+		return nil, err
+	}
+	def, err := b.graph.Compile(ctx, b.BuildContextDir, b.PubKeyPath, platform, b.Options.ProgressMode)
 	if err != nil {
 		return nil, errors.Wrap(err, "failed to compile build.envd")
 	}
@@ -176,8 +205,10 @@ func (b generalBuilder) imageConfig(ctx context.Context) (string, error) {
 
 	env := b.graph.GetEnviron()
 	user := b.graph.GetUser()
+	platform := b.graph.GetPlatform()
+	workingDir := b.graph.GetWorkingDir()
 
-	data, err := ImageConfigStr(labels, ports, ep, env, user)
+	data, err := ImageConfigStr(labels, ports, ep, env, user, workingDir, platform)
 	if err != nil {
 		return "", errors.Wrap(err, "failed to get image config")
 	}
@@ -228,22 +259,7 @@ func (b generalBuilder) build(ctx context.Context, pw progresswriter.Writer) err
 					}
 				}
 				defer pipeW.Close()
-				solveOpt := client.SolveOpt{
-					CacheExports: ce,
-					Exports:      []client.ExportEntry{entry},
-					LocalDirs: map[string]string{
-						flag.FlagCacheDir:     home.GetManager().CacheDir(),
-						flag.FlagBuildContext: b.BuildContextDir,
-					},
-					Session: attachable,
-				}
-				if b.UseHTTPProxy {
-					solveOpt.FrontendAttrs = map[string]string{
-						"build-arg:HTTPS_PROXY": os.Getenv("HTTPS_PROXY"),
-						"build-arg:HTTP_PROXY":  os.Getenv("HTTP_PROXY"),
-						"build-arg:NO_PROXY":    os.Getenv("NO_PROXY"),
-					}
-				}
+				solveOpt := constructSolveOpt(ce, &entry, b, attachable)
 				_, err := b.Client.Build(ctx, solveOpt, "envd", b.BuildFunc(), pw.Status())
 				if err != nil {
 					err = errors.Wrap(&BuildkitdErr{err: err}, "Buildkit error")
@@ -263,38 +279,43 @@ func (b generalBuilder) build(ctx context.Context, pw progresswriter.Writer) err
 				b.logger.Debug("loading image to docker host")
 				if err := dockerClient.Load(ctx, pipeR, true); err != nil {
 					err = errors.Wrap(err, "failed to load docker image")
-					b.logger.Error(err)
+					b.logger.WithError(err).Error()
 					return err
 				}
 				b.logger.Debug("loaded docker image successfully")
 				return nil
 			})
 		default:
-			eg.Go(func() error {
-				solveOpt := client.SolveOpt{
-					CacheExports: ce,
-					Exports:      []client.ExportEntry{entry},
-					LocalDirs: map[string]string{
-						flag.FlagCacheDir:     home.GetManager().CacheDir(),
-						flag.FlagBuildContext: b.BuildContextDir,
-					},
-					Session: attachable,
-				}
-				if b.UseHTTPProxy {
-					solveOpt.FrontendAttrs = map[string]string{
-						"build-arg:HTTPS_PROXY": os.Getenv("HTTPS_PROXY"),
-						"build-arg:HTTP_PROXY":  os.Getenv("HTTP_PROXY"),
-						"build-arg:NO_PROXY":    os.Getenv("NO_PROXY"),
+			func(entry client.ExportEntry) {
+				eg.Go(func() error {
+					solveOpt := constructSolveOpt(ce, &entry, b, attachable)
+					_, err := b.Client.Build(ctx, solveOpt, "envd", b.BuildFunc(), pw.Status())
+					if err != nil {
+						err = errors.Wrap(err, "failed to solve LLB")
+						return err
 					}
-				}
-				_, err := b.Client.Build(ctx, solveOpt, "envd", b.BuildFunc(), pw.Status())
-				if err != nil {
-					err = errors.Wrap(err, "failed to solve LLB")
-					return err
-				}
-				b.logger.Debug("llb def is solved successfully")
-				return nil
-			})
+					b.logger.Debug("llb def is solved successfully")
+
+					// push the image if it's moby builder and push=true
+					if !(entry.Type == "moby" && entry.Attrs["push"] == "true") {
+						return nil
+					}
+					b.logger.Debug("pushing image to registry")
+					client, err := docker.NewClient(ctx)
+					if err != nil {
+						err = errors.Wrap(err, "failed to init docker client")
+						b.logger.WithError(err).Error()
+						return err
+					}
+					if err = client.PushImage(ctx, entry.Attrs["name"], b.Platform); err != nil {
+						err = errors.Wrap(err, "failed to push image")
+						b.logger.WithError(err).Error()
+						return err
+					}
+					b.logger.Debug("pushed image:", entry.Attrs["name"])
+					return nil
+				})
+			}(entry)
 		}
 	}
 
@@ -312,10 +333,59 @@ func (b generalBuilder) build(ctx context.Context, pw progresswriter.Writer) err
 			// Close the pipe on cancels, otherwise the whole thing hangs.
 			pipeR.Close()
 			return errors.Wrap(err, "build cancelled")
-		} else {
-			return errors.Wrap(err, "failed to wait error group")
 		}
+		return errors.Wrap(err, "failed to wait error group")
 	}
 	b.logger.Debug("build successfully")
 	return nil
 }
+
+func constructSolveOpt(ce []client.CacheOptionsEntry, entry *client.ExportEntry,
+	b generalBuilder, attachable []session.Attachable) client.SolveOpt {
+	c, _ := home.GetManager().ContextGetCurrent()
+	if c.Builder == types.BuilderTypeMoby {
+		if entry.Attrs == nil {
+			entry = &client.ExportEntry{
+				Type: "moby",
+				Attrs: map[string]string{
+					"name": b.Tag,
+				},
+			}
+		} else if entry.Type == "image" {
+			entry.Type = "moby"
+		}
+	}
+	opt := client.SolveOpt{
+		CacheExports: ce,
+		Exports:      []client.ExportEntry{*entry},
+		LocalDirs: map[string]string{
+			flag.FlagCacheDir:     home.GetManager().CacheDir(),
+			flag.FlagBuildContext: b.BuildContextDir,
+		},
+		Session: attachable,
+	}
+	if b.UseHTTPProxy {
+		opt.FrontendAttrs = map[string]string{
+			"build-arg:HTTPS_PROXY": os.Getenv("HTTPS_PROXY"),
+			"build-arg:HTTP_PROXY":  os.Getenv("HTTP_PROXY"),
+			"build-arg:NO_PROXY":    os.Getenv("NO_PROXY"),
+		}
+	}
+	return opt
+}
+
+func parsePlatform(platform string) (*ocispecs.Platform, error) {
+	os, arch, variant := "linux", "amd64", ""
+	if platform == "" {
+		return &ocispecs.Platform{Architecture: arch, OS: os, Variant: variant}, nil
+	}
+	arr := strings.Split(platform, "/")
+	if len(arr) < 2 {
+		return nil, errors.New("invalid platform format, expected `os/arch[/variant]`")
+	}
+	os, arch = arr[0], arr[1]
+	if len(arr) >= 3 {
+		variant = arr[2]
+	}
+	return &ocispecs.Platform{Architecture: arch, OS: os, Variant: variant}, nil
+}
