@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -31,7 +31,7 @@ func (b generalBuilder) checkIfNeedBuild(ctx context.Context) bool {
 	depsFiles = b.GetDepsFilesHandler(depsFiles)
 	isUpdated, err := b.checkDepsFileUpdate(ctx, b.Tag, b.ManifestFilePath, depsFiles)
 	if err != nil {
-		b.logger.Debugf("failed to check manifest update: %s", err)
+		b.logger.WithError(err).Debug("failed to check manifest update")
 	}
 	if !isUpdated {
 		b.logger.Infof("manifest is not updated, skip building")
