@@ -20,18 +20,20 @@ import (
 	"time"
 
 	"github.com/docker/docker/api/types"
+
+	"github.com/tensorchord/envd/pkg/util/buildkitutil"
 )
 
 type Client interface {
 	// Load loads the image from the reader to the docker host.
 	Load(ctx context.Context, r io.ReadCloser, quiet bool) error
-	StartBuildkitd(ctx context.Context, tag, name, mirror string, timeout time.Duration) (string, error)
+	StartBuildkitd(ctx context.Context, tag, name string, config *buildkitutil.BuildkitConfig, timeout time.Duration) (string, error)
 
 	Exec(ctx context.Context, cname string, cmd []string) error
 
 	GetImageWithCacheHashLabel(ctx context.Context, image string, hash string) (types.ImageSummary, error)
 	RemoveImage(ctx context.Context, image string) error
-
+	PushImage(ctx context.Context, image, platform string) error
 	PruneImage(ctx context.Context) (types.ImagesPruneReport, error)
 
 	Stats(ctx context.Context, cname string, statChan chan<- *Stats, done <-chan bool) error
