@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ import (
 )
 
 var _ = Describe("docker", func() {
-	When("given the a lowcase tag", func() {
+	When("given the a lowercase tag", func() {
 		It("should return the tag identically", func() {
 			tag := "test:test"
 			newTag, err := NormalizeName(tag)
