@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,8 +17,8 @@ package vscode
 import "fmt"
 
 const (
-	vendorVSCodeTemplate  = "https://%s.gallery.vsassets.io/_apis/public/gallery/publisher/%s/extension/%s/%s/assetbyname/Microsoft.VisualStudio.Services.VSIXPackage"
-	vendorOpenVSXTemplate = "https://open-vsx.org/api/%s/%s/latest"
+	vendorVSCodeTemplate  = "https://%s.gallery.vsassets.io/_apis/public/gallery/publisher/%s/extension/%s/%s/assetbyname/Microsoft.VisualStudio.Services.VSIXPackage?targetPlatform=%s"
+	vendorOpenVSXTemplate = "https://open-vsx.org/api/%s/%s/latest?targetPlatform=%s"
 )
 
 type MarketplaceVendor string
@@ -31,12 +31,13 @@ const (
 type Plugin struct {
 	Publisher string
 	Extension string
+	Platform  string
 	Version   *string
 }
 
 func (p Plugin) String() string {
 	if p.Version != nil {
-		return fmt.Sprintf("%s.%s-%s", p.Publisher, p.Extension, *p.Version)
+		return fmt.Sprintf("%s.%s-%s@%s", p.Publisher, p.Extension, *p.Version, p.Platform)
 	}
-	return fmt.Sprintf("%s.%s", p.Publisher, p.Extension)
+	return fmt.Sprintf("%s.%s@%s", p.Publisher, p.Extension, p.Platform)
 }
