@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ import (
 	"encoding/json"
 	"fmt"
 	"path/filepath"
+	"runtime"
 	"strconv"
 	"strings"
 	"time"
@@ -30,10 +31,12 @@ import (
 	"github.com/docker/docker/api/types/mount"
 	"github.com/docker/docker/client"
 	"github.com/docker/go-connections/nat"
+	dockerutils "github.com/docker/go-units"
 	"github.com/sirupsen/logrus"
 
 	envdconfig "github.com/tensorchord/envd/pkg/config"
 	"github.com/tensorchord/envd/pkg/lang/ir"
+	"github.com/tensorchord/envd/pkg/lang/version"
 	"github.com/tensorchord/envd/pkg/ssh"
 	sshconfig "github.com/tensorchord/envd/pkg/ssh/config"
 	"github.com/tensorchord/envd/pkg/types"
@@ -187,6 +190,35 @@ func (e dockerEngine) ListImageDependency(ctx context.Context, image string) (*t
 	return dep, nil
 }
 
+func (e dockerEngine) getVerFromImageLabel(ctx context.Context, env string) (version.Getter, error) {
+	ctr, err := e.GetImage(ctx, env)
+	if err != nil {
+		return nil, errors.Wrapf(err, "failed to inspect image: %s", env)
+	}
+	ver, ok := ctr.Labels[types.ImageLabelSyntaxVer]
+	if !ok {
+		return version.NewByVersion("v0"), nil
+	}
+	return version.NewByVersion(ver), nil
+}
+
+func (e dockerEngine) listEnvGeneralGraph(ctx context.Context, env string, g ir.Graph) (ir.Graph, error) {
+	ctr, err := e.GetImage(ctx, env)
+	if err != nil {
+		return nil, errors.Wrapf(err, "failed to inspect image: %s", env)
+	}
+	code, ok := ctr.Labels[types.GeneralGraphCode]
+	if !ok {
+		return nil, errors.Newf("failed to get runtime graph label from image: %s", env)
+	}
+	logrus.WithField("env", env).Debugf("general graph: %s", code)
+	newg, err := g.GeneralGraphFromLabel([]byte(code))
+	if err != nil {
+		return nil, errors.Wrapf(err, "failed to create runtime graph from the image: %s", env)
+	}
+	return newg, err
+}
+
 func (e dockerEngine) ListEnvRuntimeGraph(ctx context.Context, env string) (*ir.RuntimeGraph, error) {
 	ctr, err := e.ContainerInspect(ctx, env)
 	if err != nil {
@@ -318,8 +350,17 @@ func (e dockerEngine) StartEnvd(ctx context.Context, so StartOptions) (*StartRes
 		"tag":           so.Image,
 		"environment":   so.EnvironmentName,
 		"gpu":           so.NumGPU,
+		"shm":           so.ShmSize,
+		"cpu":           so.NumCPU,
+		"cpu-set":       so.CPUSet,
+		"memory":        so.NumMem,
 		"build-context": so.BuildContext,
 	})
+
+	bar := InitProgressBar(5)
+	defer bar.Finish()
+	bar.UpdateTitle("configure the environment")
+
 	if so.NumGPU != 0 {
 		nvruntimeExists, err := e.GPUEnabled(ctx)
 		if err != nil {
@@ -346,12 +387,30 @@ func (e dockerEngine) StartEnvd(ctx context.Context, so StartOptions) (*StartRes
 	base := fileutil.EnvdHomeDir(filepath.Base(so.BuildContext))
 	config.WorkingDir = base
 
+	var g ir.Graph
+	if so.Image == "" {
+		g = so.DockerSource.Graph
+	} else {
+		// Use specified image as the running image
+		getter, err := e.getVerFromImageLabel(ctx, so.Image)
+		if err != nil {
+			return nil, errors.Wrap(err, "failed to get the version from the image label")
+		}
+		defaultGraph := getter.GetDefaultGraph()
+		if err != nil {
+			return nil, errors.Wrap(err, "failed to get the graph from the image")
+		}
+		g, err = e.listEnvGeneralGraph(ctx, so.Image, defaultGraph)
+		if err != nil {
+			return nil, errors.Wrap(err, "failed to get the graph from the image")
+		}
+		so.DockerSource.Graph = g
+	}
+
 	if so.DockerSource == nil || so.DockerSource.Graph == nil {
 		return nil, errors.New("failed to get the docker-specific options")
 	}
 
-	g := so.DockerSource.Graph
-
 	mountOption := make([]mount.Mount, 0,
 		len(so.DockerSource.MountOptions)+len(g.GetMount())+1)
 	for _, option := range so.DockerSource.MountOptions {
@@ -406,6 +465,30 @@ func (e dockerEngine) StartEnvd(ctx context.Context, so StartOptions) (*StartRes
 	if so.ShmSize > 0 {
 		hostConfig.ShmSize = int64(so.ShmSize) * 1024 * 1024
 	}
+	// resource
+	if len(so.NumCPU) > 0 {
+		cpu, err := strconv.ParseFloat(so.NumCPU, 64)
+		if err != nil {
+			logger.Infof("parse `cpu` error: %v, ignore this argument", err)
+		} else if runtime.GOOS == "windows" {
+			hostConfig.NanoCPUs = int64(cpu * 10e9)
+		} else {
+			// refer to https://docs.docker.com/config/containers/resource_constraints/#configure-the-default-cfs-scheduler
+			// CPU quota and CPU period only work for UNIX platform
+			hostConfig.CPUQuota = int64(cpu * 10e5)
+		}
+	}
+	if len(so.CPUSet) > 0 {
+		hostConfig.CpusetCpus = so.CPUSet
+	}
+	if len(so.NumMem) > 0 {
+		mem, err := dockerutils.RAMInBytes(so.NumMem)
+		if err != nil {
+			logger.WithError(err).Info("parse `memory` error, ignore this argument")
+		} else {
+			hostConfig.Memory = mem
+		}
+	}
 
 	// Configure ssh port.
 	natPort := nat.Port(fmt.Sprintf("%d/tcp", envdconfig.SSHPortInContainer))
@@ -491,6 +574,7 @@ func (e dockerEngine) StartEnvd(ctx context.Context, so StartOptions) (*StartRes
 	})
 	logger.Debugf("starting %s container", so.EnvironmentName)
 
+	bar.UpdateTitle("create the environment")
 	resp, err := e.ContainerCreate(ctx, config, hostConfig, nil, nil, so.EnvironmentName)
 	if err != nil {
 		return nil, errors.Wrap(err, "failed to create the container")
@@ -500,12 +584,13 @@ func (e dockerEngine) StartEnvd(ctx context.Context, so StartOptions) (*StartRes
 		logger.Warnf("run with warnings: %s", w)
 	}
 
+	bar.UpdateTitle("start the environment")
 	if err := e.ContainerStart(
 		ctx, resp.ID, dockertypes.ContainerStartOptions{}); err != nil {
 		errCause := errors.UnwrapAll(err)
 		// Hack to check if the port is already allocated.
 		if strings.Contains(errCause.Error(), "port is already allocated") {
-			logrus.Debugf("failed to allocate the port: %s", err)
+			logger.WithError(err).Debug("failed to allocate the port")
 			return nil, errors.New("port is already allocated in the host")
 		}
 		return nil, errors.Wrap(err, "failed to run the container")
@@ -516,11 +601,13 @@ func (e dockerEngine) StartEnvd(ctx context.Context, so StartOptions) (*StartRes
 		return nil, errors.Wrap(err, "failed to inspect the container")
 	}
 
+	bar.UpdateTitle("wait for the environment to start")
 	if err := e.WaitUntilRunning(
 		ctx, container.Name, so.Timeout); err != nil {
 		return nil, errors.Wrap(err, "failed to wait until the container is running")
 	}
 
+	bar.UpdateTitle("attach the environment")
 	result := &StartResult{
 		SSHPort: sshPortInHost,
 		Address: container.NetworkSettings.IPAddress,
@@ -566,7 +653,7 @@ func (e dockerEngine) Destroy(ctx context.Context, name string) (string, error)
 	if _, err := e.ImageRemove(ctx, ctr.Image, dockertypes.ImageRemoveOptions{}); err != nil {
 		return "", errors.Errorf("remove image %s failed: %w", ctr.Image, err)
 	}
-	logrus.Infof("image(%s) is destroyed", ctr.Image)
+	logger.Infof("image(%s) is destroyed", ctr.Image)
 
 	return name, nil
 }
@@ -619,9 +706,8 @@ func (e dockerEngine) GPUEnabled(ctx context.Context) (bool, error) {
 	} else if strings.HasSuffix(info.KernelVersion, "WSL2") {
 		logrus.Warn("We couldn't detect if your runtime support GPU on WSL2, we will continue to run your environment.")
 		return true, nil
-	} else {
-		return false, nil
 	}
+	return false, nil
 }
 
 func (e dockerEngine) GetImage(ctx context.Context, image string) (types.EnvdImage, error) {
