@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -68,14 +68,13 @@ func New(ctx context.Context, opt Options) (Engine, error) {
 			Client:    cli,
 			Loginname: ac.Name,
 		}, nil
-	} else {
-		cli, err := client.NewClientWithOpts(
-			client.FromEnv, client.WithAPIVersionNegotiation())
-		if err != nil {
-			return nil, errors.Wrap(err, "failed to create the docker client")
-		}
-		return &dockerEngine{
-			Client: cli,
-		}, nil
 	}
+	cli, err := client.NewClientWithOpts(
+		client.FromEnv, client.WithAPIVersionNegotiation())
+	if err != nil {
+		return nil, errors.Wrap(err, "failed to create the docker client")
+	}
+	return &dockerEngine{
+		Client: cli,
+	}, nil
 }
