@@ -1,16 +1,17 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
 // You may obtain a copy of the License at
 //
-//	http://www.apache.org/licenses/LICENSE-2.0
+//      http://www.apache.org/licenses/LICENSE-2.0
 //
 // Unless required by applicable law or agreed to in writing, software
 // distributed under the License is distributed on an "AS IS" BASIS,
 // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 // See the License for the specific language governing permissions and
 // limitations under the License.
+
 package home
 
 import (
@@ -23,10 +24,10 @@ import (
 
 var _ = Describe("auth test", Ordered, func() {
 	defaultAuthName := "auth_name"
-	deafultJWTToken := "default_token"
+	defaultJWTToken := "default_token"
 	ac := types.AuthConfig{
 		Name:     defaultAuthName,
-		JWTToken: deafultJWTToken,
+		JWTToken: defaultJWTToken,
 	}
 
 	BeforeEach(func() {
