@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -29,6 +29,7 @@ type Manager interface {
 	contextManager
 	cacheManager
 	dataManager
+	authManager
 }
 
 type generalManager struct {
@@ -36,10 +37,12 @@ type generalManager struct {
 	cacheStatusFile string
 	configFile      string
 	contextFile     string
+	authFile        string
 
 	// TODO(gaocegege): Abstract CacheManager.
 	cacheMap map[string]bool
 	context  types.EnvdContext
+	auth     types.EnvdAuth
 
 	logger *logrus.Entry
 }
@@ -57,9 +60,11 @@ func Initialize() error {
 				Current: "default",
 				Contexts: []types.Context{
 					{
-						Name:          "default",
-						Builder:       types.BuilderTypeDocker,
-						BuilderSocket: "envd_buildkitd",
+						Name:           "default",
+						Builder:        types.BuilderTypeDocker,
+						BuilderAddress: "envd_buildkitd",
+						Runner:         types.RunnerTypeDocker,
+						RunnerAddress:  nil,
 					},
 				},
 			},
@@ -85,6 +90,10 @@ func (m *generalManager) init() error {
 		return errors.Wrap(err, "failed to initialize cache")
 	}
 
+	if err := m.initAuth(); err != nil {
+		return errors.Wrap(err, "failed to initialize auth")
+	}
+
 	if err := sshconfig.GenerateKeys(); err != nil {
 		return errors.Wrap(err, "failed to generate ssh key")
 	}
