@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -46,9 +46,29 @@ var Module = &starlarkstruct.Module{
 		"entrypoint":     starlark.NewBuiltin(ruleEntrypoint, ruleFuncEntrypoint),
 		"repo":           starlark.NewBuiltin(ruleRepo, ruleFuncRepo),
 		"owner":          starlark.NewBuiltin(ruleOwner, ruleFuncOwner),
+		"shm_size":       starlark.NewBuiltin(ruleShmSize, ruleFuncShmSize),
 	},
 }
 
+func ruleFuncShmSize(thread *starlark.Thread, _ *starlark.Builtin, args starlark.Tuple, kwargs []starlark.Tuple) (starlark.Value, error) {
+	var shmSize starlark.Int
+
+	if err := starlark.UnpackArgs(ruleShmSize, args, kwargs, "size", &shmSize); err != nil {
+		return nil, err
+	}
+
+	shmSizeInt, ok := shmSize.Int64()
+
+	if ok {
+		ir.ShmSize(int(shmSizeInt))
+		logger.Debugf("Using %d shm size", int(shmSizeInt))
+	} else {
+		logger.Debugf("Failed to convert shm size to int64")
+	}
+
+	return starlark.None, nil
+}
+
 func ruleFuncGPU(thread *starlark.Thread, _ *starlark.Builtin,
 	args starlark.Tuple, kwargs []starlark.Tuple) (starlark.Value, error) {
 	var numGPUs starlark.Int
