@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -24,6 +24,7 @@ import (
 
 	"github.com/cockroachdb/errors"
 	"github.com/moby/buildkit/client/llb"
+	ocispecs "github.com/opencontainers/image-spec/specs-go/v1"
 	"github.com/sirupsen/logrus"
 	"github.com/spf13/viper"
 	servertypes "github.com/tensorchord/envd-server/api/types"
@@ -46,7 +47,8 @@ func NewGraph() ir.Graph {
 	langVersion := languageVersionDefault
 	conda := &ir.CondaConfig{}
 	return &generalGraph{
-		OS: osDefault,
+		OS:                osDefault,
+		EnvdSyntaxVersion: "v0",
 		Language: ir.Language{
 			Name:    languageDefault,
 			Version: &langVersion,
@@ -54,6 +56,7 @@ func NewGraph() ir.Graph {
 		CUDA:    nil,
 		CUDNN:   CUDNNVersionDefault,
 		NumGPUs: 0,
+		ShmSize: 0,
 
 		PyPIPackages:    [][]string{},
 		RPackages:       []string{},
@@ -64,11 +67,21 @@ func NewGraph() ir.Graph {
 		Shell:           shellBASH,
 		CondaConfig:     conda,
 		RuntimeGraph:    runtimeGraph,
+		Platform:        &ocispecs.Platform{},
+		WorkingDir:      "/",
 	}
 }
 
 var DefaultGraph = NewGraph()
 
+func (g generalGraph) IsDev() bool {
+	return g.Image == nil
+}
+
+func (g generalGraph) GetShmSize() int {
+	return g.ShmSize
+}
+
 func (g generalGraph) GetNumGPUs() int {
 	return g.NumGPUs
 }
@@ -105,14 +118,24 @@ func (g generalGraph) GetUser() string {
 	return "envd"
 }
 
-func (g *generalGraph) Compile(ctx context.Context, envName string, pub string) (*llb.Definition, error) {
-	w, err := compileui.New(ctx, os.Stdout, "auto")
+func (g generalGraph) GetPlatform() *ocispecs.Platform {
+	return g.Platform
+}
+
+func (g generalGraph) GetWorkingDir() string {
+	return g.WorkingDir
+}
+
+func (g *generalGraph) Compile(ctx context.Context, envPath string, pub string, platform *ocispecs.Platform, progressMode string) (*llb.Definition, error) {
+	w, err := compileui.New(ctx, os.Stdout, progressMode)
 	if err != nil {
 		return nil, errors.Wrap(err, "failed to create compileui")
 	}
 	g.Writer = w
-	g.EnvironmentName = envName
+	g.EnvironmentPath = envPath
+	g.EnvironmentName = filepath.Base(envPath)
 	g.PublicKeyPath = pub
+	g.Platform = platform
 
 	uid, gid, err := getUIDGID()
 	if err != nil {
@@ -122,8 +145,7 @@ func (g *generalGraph) Compile(ctx context.Context, envName string, pub string)
 	if err != nil {
 		return nil, errors.Wrap(err, "failed to compile the graph")
 	}
-	// TODO(gaocegege): Support multi platform.
-	def, err := state.Marshal(ctx, llb.LinuxAmd64)
+	def, err := state.Marshal(ctx, llb.Platform(*g.Platform))
 	if err != nil {
 		return nil, errors.Wrap(err, "failed to marshal the llb definition")
 	}
@@ -136,6 +158,9 @@ func (g generalGraph) GPUEnabled() bool {
 
 func (g generalGraph) Labels() (map[string]string, error) {
 	labels := make(map[string]string)
+
+	labels[types.ImageLabelSyntaxVer] = g.EnvdSyntaxVersion
+
 	str, err := json.Marshal(g.SystemPackages)
 	if err != nil {
 		return nil, err
@@ -166,6 +191,11 @@ func (g generalGraph) Labels() (map[string]string, error) {
 		return labels, err
 	}
 	labels[types.RuntimeGraphCode] = code
+	code, err = g.Dump()
+	if err != nil {
+		return labels, err
+	}
+	labels[types.GeneralGraphCode] = code
 
 	ports := []servertypes.EnvironmentPort{}
 	ports = append(ports, servertypes.EnvironmentPort{
@@ -206,7 +236,7 @@ func (g generalGraph) Labels() (map[string]string, error) {
 	}
 	labels[types.ImageLabelRepo] = string(repoInfo)
 
-	labels[types.ImageLabelContainerName] = string(g.EnvironmentName)
+	labels[types.ImageLabelContainerName] = g.EnvironmentName
 	return labels, nil
 }
 
