@@ -11,5 +11,5 @@ mkdir -p ${MAMBA_BIN_DIR} && \
 curl -Ls https://micro.mamba.pm/api/micromamba/linux-${ARCH}/${MAMBA_VERSION} | tar -xvj -C ${MAMBA_BIN_DIR} --strip-components=1 bin/micromamba && \
 chown $(id -u):$(id -g) ${MAMBA_BIN_DIR}/micromamba
 ln -s ${MAMBA_BIN_DIR}/micromamba ${MAMBA_BIN_DIR}/conda && \
-echo -e "channels:\n  - conda-forge" > ${MAMBA_ROOT_PREFIX}/.mambarc
+echo -e "channels:\n  - defaults" > ${MAMBA_ROOT_PREFIX}/.mambarc
 echo -e "#!/bin/sh\n\. ${MAMBA_ROOT_PREFIX}/etc/profile.d/micromamba.sh || return \$?\nmicromamba activate \"\$@\"" > ${MAMBA_BIN_DIR}/activate
