@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -17,6 +17,7 @@ package v0
 import (
 	"github.com/cockroachdb/errors"
 	"github.com/opencontainers/go-digest"
+	"github.com/sirupsen/logrus"
 
 	"github.com/tensorchord/envd/pkg/editor/vscode"
 	"github.com/tensorchord/envd/pkg/lang/ir"
@@ -35,9 +36,13 @@ func Base(os, language, image string) error {
 	}
 	if len(os) > 0 {
 		g.OS = os
+		logrus.Warn("`os` only affects the GPU base image. If you want to use a different base image, " +
+			"envd v1 has better support. Check the doc https://envd.tensorchord.ai/guide/v1.html")
 	}
 	if image != "" {
 		g.Image = &image
+		logrus.Warn("Custom base image can only be used in non-dev env for envd v0. " +
+			"For better custom image support, check the envd v1 doc https://envd.tensorchord.ai/guide/v1.html")
 	}
 	return nil
 }
@@ -75,6 +80,12 @@ func SystemPackage(deps []string) {
 	g.SystemPackages = append(g.SystemPackages, deps...)
 }
 
+func ShmSize(shmSize int) {
+	g := DefaultGraph.(*generalGraph)
+
+	g.ShmSize = shmSize
+}
+
 func GPU(numGPUs int) {
 	g := DefaultGraph.(*generalGraph)
 
