@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -106,11 +106,11 @@ func (g generalGraph) compileZSH(root llb.State) (llb.State, error) {
 	ohMyZSHPath := fileutil.EnvdHomeDir(".oh-my-zsh")
 	m := shell.NewManager()
 	g.Writer.LogZSH(compileui.ActionStart, false)
-	if cached, err := m.DownloadOrCache(); err != nil {
+	cached, err := m.DownloadOrCache()
+	if err != nil {
 		return llb.State{}, errors.Wrap(err, "failed to download oh-my-zsh")
-	} else {
-		g.Writer.LogZSH(compileui.ActionEnd, cached)
 	}
+	g.Writer.LogZSH(compileui.ActionEnd, cached)
 	zshStage := root.
 		File(llb.Copy(llb.Local(flag.FlagCacheDir), "oh-my-zsh", ohMyZSHPath,
 			&llb.CopyInfo{CreateDestPath: true}, llb.WithUIDGID(g.uid, g.gid))).
