@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -86,6 +86,7 @@ func (g generalGraph) compileCopy(root llb.State) llb.State {
 	for _, c := range g.Copy {
 		result = result.File(llb.Copy(
 			llb.Local(flag.FlagBuildContext), c.Source, c.Destination,
+			&llb.CopyInfo{CreateDestPath: true},
 			llb.WithUIDGID(g.uid, g.gid)))
 	}
 	return result
@@ -149,6 +150,9 @@ func (g *generalGraph) preparePythonBase(root llb.State) llb.State {
 	for _, env := range types.BaseEnvironment {
 		root = root.AddEnv(env.Name, env.Value)
 	}
+	for k, v := range g.RuntimeEnviron {
+		root = root.AddEnv(k, v)
+	}
 
 	// apt packages
 	var sb strings.Builder
@@ -157,7 +161,6 @@ func (g *generalGraph) preparePythonBase(root llb.State) llb.State {
 	sb.WriteString(strings.Join(types.BaseAptPackage, " "))
 	sb.WriteString("&& rm -rf /var/lib/apt/lists/* ")
 	// shell prompt
-	sb.WriteString("&& curl --proto '=https' --tlsv1.2 -sSf https://starship.rs/install.sh | sh -s -- -y")
 	sb.WriteString("&& locale-gen en_US.UTF-8")
 
 	run := root.Run(llb.Shlexf(`bash -c "%s"`, sb.String()),
@@ -174,6 +177,14 @@ func (g generalGraph) compileSSHD(root llb.State) llb.State {
 	return sshd
 }
 
+func (g generalGraph) compileStarship(root llb.State) llb.State {
+	starship := root.File(llb.Copy(
+		llb.Image(types.EnvdStarshipImage), "/usr/local/bin/starship", "/usr/local/bin/starship",
+		&llb.CopyInfo{CreateDestPath: true}),
+		llb.WithCustomName(fmt.Sprintf("[internal] add envd-starship from %s", types.EnvdStarshipImage)))
+	return starship
+}
+
 func (g *generalGraph) compileBase() (llb.State, error) {
 	logger := logrus.WithFields(logrus.Fields{
 		"os":       g.OS,
@@ -213,11 +224,14 @@ func (g *generalGraph) compileBase() (llb.State, error) {
 		base = g.compileCUDAPackages("nvidia/cuda")
 	}
 
+	g.WorkingDir = g.getWorkingDir()
+
 	// Install conda first.
 	condaStage := g.installConda(base)
 	supervisor := g.installHorust(condaStage)
 	sshdStage := g.compileSSHD(supervisor)
-	source, err := g.compileExtraSource(sshdStage)
+	starshipStage := g.compileStarship(sshdStage)
+	source, err := g.compileExtraSource(starshipStage)
 	if err != nil {
 		return llb.State{}, errors.Wrap(err, "failed to get extra sources")
 	}
