@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -15,6 +15,8 @@
 package v0
 
 import (
+	ocispecs "github.com/opencontainers/image-spec/specs-go/v1"
+
 	"github.com/tensorchord/envd/pkg/editor/vscode"
 	"github.com/tensorchord/envd/pkg/lang/ir"
 	"github.com/tensorchord/envd/pkg/progress/compileui"
@@ -30,12 +32,14 @@ type generalGraph struct {
 
 	OS string
 	ir.Language
-	Image *string
+	EnvdSyntaxVersion string
+	Image             *string
 
 	Shell   string
 	CUDA    *string
 	CUDNN   string
 	NumGPUs int
+	ShmSize int
 
 	UbuntuAPTSource    *string
 	CRANMirrorURL      *string
@@ -69,13 +73,20 @@ type generalGraph struct {
 	*ir.CondaConfig
 	*ir.RStudioServerConfig
 
-	Writer compileui.Writer
+	Writer compileui.Writer `json:"-"`
 	// EnvironmentName is the base name of the environment.
 	// It is the BaseDir(BuildContextDir)
 	// e.g. mnist, streamlit-mnist
 	EnvironmentName string
+	// EnvironmentPath is the full path of this environment.
+	EnvironmentPath string
+	// WorkingDir is the working directory of this environment.
+	// This only affect the `WorkingDir` in the image config.
+	WorkingDir string
 
 	ir.RuntimeGraph
+
+	Platform *ocispecs.Platform
 }
 
 const (
