@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -24,10 +24,12 @@ import (
 
 	"github.com/cockroachdb/errors"
 	"github.com/moby/buildkit/client/llb"
+	ocispecs "github.com/opencontainers/image-spec/specs-go/v1"
 	"github.com/sirupsen/logrus"
 	servertypes "github.com/tensorchord/envd-server/api/types"
 
 	"github.com/tensorchord/envd/pkg/config"
+	"github.com/tensorchord/envd/pkg/home"
 	"github.com/tensorchord/envd/pkg/lang/ir"
 	"github.com/tensorchord/envd/pkg/progress/compileui"
 	"github.com/tensorchord/envd/pkg/types"
@@ -38,16 +40,17 @@ func NewGraph() ir.Graph {
 	runtimeGraph := ir.RuntimeGraph{
 		RuntimeCommands: make(map[string]string),
 		RuntimeEnviron:  make(map[string]string),
-		RuntimeEnvPaths: []string{types.DefaultSystemPath},
+		RuntimeEnvPaths: strings.Split(types.DefaultSystemPath, ":"),
 	}
 	return &generalGraph{
-		uid:      -1,
-		gid:      -1,
-		Image:    defaultImage,
-		Language: ir.Language{},
-		CUDA:     nil,
-		CUDNN:    CUDNNVersionDefault,
-		NumGPUs:  0,
+		uid:               -1,
+		gid:               -1,
+		Image:             defaultImage,
+		CUDA:              nil,
+		CUDNN:             CUDNNVersionDefault,
+		NumGPUs:           0,
+		ShmSize:           0,
+		EnvdSyntaxVersion: "v1",
 
 		PyPIPackages:    [][]string{},
 		RPackages:       [][]string{},
@@ -57,6 +60,8 @@ func NewGraph() ir.Graph {
 		UserDirectories: []string{},
 		Shell:           shellBASH,
 		RuntimeGraph:    runtimeGraph,
+		Platform:        &ocispecs.Platform{},
+		WorkingDir:      "/",
 	}
 }
 
@@ -66,10 +71,18 @@ func (g *generalGraph) SetWriter(w compileui.Writer) {
 	g.Writer = w
 }
 
+func (g generalGraph) IsDev() bool {
+	return g.Dev
+}
+
 func (g generalGraph) GetHTTP() []ir.HTTPInfo {
 	return g.HTTP
 }
 
+func (g generalGraph) GetShmSize() int {
+	return g.ShmSize
+}
+
 func (g generalGraph) GetNumGPUs() int {
 	return g.NumGPUs
 }
@@ -102,14 +115,32 @@ func (g generalGraph) GetRuntimeCommands() map[string]string {
 	return g.RuntimeCommands
 }
 
-func (g *generalGraph) Compile(ctx context.Context, envName string, pub string) (*llb.Definition, error) {
-	w, err := compileui.New(ctx, os.Stdout, "auto")
+func (g generalGraph) GetPlatform() *ocispecs.Platform {
+	return g.Platform
+}
+
+func (g generalGraph) GetWorkingDir() string {
+	return g.WorkingDir
+}
+
+func (g *generalGraph) Compile(ctx context.Context, envPath string, pub string, platform *ocispecs.Platform, progressMode string) (*llb.Definition, error) {
+	w, err := compileui.New(ctx, os.Stdout, progressMode)
 	if err != nil {
 		return nil, errors.Wrap(err, "failed to create compileui")
 	}
+	c, err := home.GetManager().ContextGetCurrent()
+	if err != nil {
+		return nil, errors.Wrap(err, "failed to get the current envd context")
+	}
+
 	g.Writer = w
-	g.EnvironmentName = envName
+	g.EnvironmentPath = envPath
+	g.EnvironmentName = filepath.Base(envPath)
 	g.PublicKeyPath = pub
+	g.Platform = platform
+	if c.Builder == types.BuilderTypeMoby {
+		g.DisableMergeOp = true
+	}
 
 	uid, gid, err := g.getUIDGID()
 	if err != nil {
@@ -119,8 +150,7 @@ func (g *generalGraph) Compile(ctx context.Context, envName string, pub string)
 	if err != nil {
 		return nil, errors.Wrap(err, "failed to compile the graph")
 	}
-	// TODO(gaocegege): Support multi platform.
-	def, err := state.Marshal(ctx, llb.LinuxAmd64)
+	def, err := state.Marshal(ctx, llb.Platform(*g.Platform))
 	if err != nil {
 		return nil, errors.Wrap(err, "failed to marshal the llb definition")
 	}
@@ -144,6 +174,9 @@ func (g generalGraph) GPUEnabled() bool {
 
 func (g generalGraph) Labels() (map[string]string, error) {
 	labels := make(map[string]string)
+
+	labels[types.ImageLabelSyntaxVer] = g.EnvdSyntaxVersion
+
 	str, err := json.Marshal(g.SystemPackages)
 	if err != nil {
 		return nil, err
@@ -175,6 +208,12 @@ func (g generalGraph) Labels() (map[string]string, error) {
 	}
 	labels[types.RuntimeGraphCode] = code
 
+	code, err = g.Dump()
+	if err != nil {
+		return labels, err
+	}
+	labels[types.GeneralGraphCode] = code
+
 	ports := []servertypes.EnvironmentPort{}
 	ports = append(ports, servertypes.EnvironmentPort{
 		Name: "ssh",
@@ -214,7 +253,7 @@ func (g generalGraph) Labels() (map[string]string, error) {
 	}
 	labels[types.ImageLabelRepo] = string(repoInfo)
 
-	labels[types.ImageLabelContainerName] = string(g.EnvironmentName)
+	labels[types.ImageLabelContainerName] = g.EnvironmentName
 	return labels, nil
 }
 
@@ -246,6 +285,9 @@ func (g generalGraph) ExposedPorts() (map[string]struct{}, error) {
 func (g generalGraph) EnvString() []string {
 	var envs []string
 	for k, v := range g.RuntimeEnviron {
+		if k == "PATH" {
+			continue
+		}
 		envs = append(envs, fmt.Sprintf("%s=%s", k, v))
 	}
 	envs = append(envs, fmt.Sprintf("PATH=%s", strings.Join(g.RuntimeEnvPaths, ":")))
@@ -277,36 +319,42 @@ func (g *generalGraph) CompileLLB(uid, gid int) (llb.State, error) {
 	if err != nil {
 		return llb.State{}, errors.Wrap(err, "failed to get the base image")
 	}
+	aptMirror := g.compileUbuntuAPT(base)
 
 	// prepare dev env: stable operations should be done here to make it cache friendly
 	if g.Dev {
-		dev := g.compileDevPackages(base)
+		dev := g.compileDevPackages(aptMirror)
 		sshd := g.compileSSHD(dev)
 		horust := g.installHorust(sshd)
-		userGroup := g.compileUserGroup(horust)
-		base = userGroup
+		starship := g.compileStarship(horust)
+		userGroup := g.compileUserGroup(starship)
+		aptMirror = userGroup
 	}
 
-	lang, err := g.compileLanguage(base)
-	if err != nil {
-		return llb.State{}, errors.Wrap(err, "failed to compile language")
-	}
-	aptMirror := g.compileUbuntuAPT(base)
 	systemPackages := g.compileSystemPackages(aptMirror)
-	merge := llb.Merge([]llb.State{
-		base,
-		llb.Diff(base, lang, llb.WithCustomName("[internal] prepare language")),
-		llb.Diff(base, systemPackages, llb.WithCustomName("[internal] install system packages")),
-	}, llb.WithCustomName("[internal] language environment and system packages"))
-	packages := g.compileLanguagePackages(merge)
+	var language llb.State
+	if g.DisableMergeOp {
+		language, err = g.compileLanguage(systemPackages)
+		if err != nil {
+			return llb.State{}, errors.Wrap(err, "failed to compile language from system packages")
+		}
+	} else {
+		lang, err := g.compileLanguage(aptMirror)
+		if err != nil {
+			return llb.State{}, errors.Wrap(err, "failed to compile language from apt mirror")
+		}
+		language = llb.Merge([]llb.State{
+			base,
+			llb.Diff(base, systemPackages, llb.WithCustomName("[internal] install system packages")),
+			llb.Diff(base, lang, llb.WithCustomName("[internal] prepare language")),
+		}, llb.WithCustomName("[internal] language environment and system packages"))
+	}
+	packages := g.compileLanguagePackages(language)
 	if err != nil {
 		return llb.State{}, errors.Wrap(err, "failed to compile language")
 	}
 
-	source, err := g.compileExtraSource(packages)
-	if err != nil {
-		return llb.State{}, errors.Wrap(err, "failed to compile extra source")
-	}
+	source := g.compileExtraSource(packages)
 	copy := g.compileCopy(source)
 
 	// dev postprocessing: related to UID, which may not be cached
@@ -326,14 +374,11 @@ func (g *generalGraph) CompileLLB(uid, gid int) (llb.State, error) {
 		if err != nil {
 			return llb.State{}, errors.Wrap(err, "failed to compile entrypoint")
 		}
-		vscode, err := g.compileVSCode()
+		vscode, err := g.compileVSCode(entrypoint)
 		if err != nil {
 			return llb.State{}, errors.Wrap(err, "failed to compile VSCode extensions")
 		}
-		copy = llb.Merge([]llb.State{
-			entrypoint,
-			vscode,
-		}, llb.WithCustomName("[internal] final dev environment"))
+		copy = vscode
 	}
 
 	// it's necessary to exec `run` with the desired user
