@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -43,10 +43,10 @@ func Python(version string) error {
 	}
 	g := DefaultGraph.(*generalGraph)
 
-	g.Language = ir.Language{
+	g.Languages = append(g.Languages, ir.Language{
 		Name:    "python",
 		Version: &version,
-	}
+	})
 	return nil
 }
 
@@ -61,17 +61,17 @@ func Conda(mamba bool) {
 func RLang() {
 	g := DefaultGraph.(*generalGraph)
 
-	g.Language = ir.Language{
+	g.Languages = append(g.Languages, ir.Language{
 		Name: "r",
-	}
+	})
 }
 
 func Julia() {
 	g := DefaultGraph.(*generalGraph)
 
-	g.Language = ir.Language{
+	g.Languages = append(g.Languages, ir.Language{
 		Name: "julia",
-	}
+	})
 }
 
 func PyPIPackage(deps []string, requirementsFile string, wheels []string) error {
@@ -121,6 +121,12 @@ func SystemPackage(deps []string) {
 	g.SystemPackages = append(g.SystemPackages, deps...)
 }
 
+func ShmSize(shmSize int) {
+	g := DefaultGraph.(*generalGraph)
+
+	g.ShmSize = shmSize
+}
+
 func GPU(numGPUs int) {
 	g := DefaultGraph.(*generalGraph)
 
@@ -246,6 +252,9 @@ func CondaChannel(channel string) error {
 func CondaPackage(deps []string, channel []string, envFile string) error {
 	g := DefaultGraph.(*generalGraph)
 
+	if g.CondaConfig == nil {
+		return errors.New("cannot install conda packages when conda is not installed")
+	}
 	g.CondaConfig.CondaPackages = append(
 		g.CondaConfig.CondaPackages, deps...)
 
@@ -258,12 +267,13 @@ func CondaPackage(deps []string, channel []string, envFile string) error {
 	return nil
 }
 
-func Copy(src, dest string) {
+func Copy(src, dest, image string) {
 	g := DefaultGraph.(*generalGraph)
 
 	g.Copy = append(g.Copy, ir.CopyInfo{
 		Source:      src,
 		Destination: dest,
+		Image:       image,
 	})
 }
 
