@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -68,11 +68,16 @@ func (g *generalGraph) installPython(root llb.State) (llb.State, error) {
 }
 
 func (g generalGraph) getAppropriatePythonVersion() (string, error) {
-	if g.Language.Version == nil {
-		return PythonVersionDefault, nil
+	var version string
+	for _, language := range g.Languages {
+		if language.Name == "python" {
+			if language.Version == nil {
+				return PythonVersionDefault, nil
+			}
+			version = *language.Version
+		}
 	}
 
-	version := *g.Language.Version
 	if version == "3" || version == "" {
 		return PythonVersionDefault, nil
 	}
@@ -126,15 +131,25 @@ func (g generalGraph) compilePyPIPackages(root llb.State) llb.State {
 	if g.RequirementsFile != nil {
 		logrus.WithField("file", *g.RequirementsFile).
 			Debug("Configure pip install requirements statements")
-		root = root.Dir(g.getWorkingDir())
-		run := root.
-			Run(llb.Shlexf("python -m pip install -r %s", *g.RequirementsFile),
-				llb.WithCustomNamef("pip install -r %s", *g.RequirementsFile))
-		run.AddMount(cacheDir, cache,
-			llb.AsPersistentCacheDir(g.CacheID(cacheDir), llb.CacheMountShared), llb.SourcePath("/cache/pip"))
-		run.AddMount(g.getWorkingDir(),
-			llb.Local(flag.FlagBuildContext))
-		root = run.Root()
+		dependencies, safeToCopy := g.IsRequirementsFileSafeToCopyContent()
+		logrus.WithField("safeToCopy", safeToCopy).WithField("dependencies", dependencies).
+			Debug("Is requirements file safe to copy")
+		if safeToCopy {
+			// avoid mounting host directory to make it cache friendly
+			root = root.Run(llb.Shlexf(
+				"python -m pip install %s",
+				strings.Join(dependencies, " ")),
+				llb.WithCustomNamef("[internal] pip install from %s with %s", *g.RequirementsFile, strings.Join(dependencies, " ")),
+			).Root()
+		} else {
+			run := root.Dir(g.getWorkingDir()).
+				Run(llb.Shlexf("python -m pip install -r %s", *g.RequirementsFile),
+					llb.WithCustomNamef("[internal] pip install -r %s", *g.RequirementsFile))
+			run.AddMount(cacheDir, cache,
+				llb.AsPersistentCacheDir(g.CacheID(cacheDir), llb.CacheMountShared), llb.SourcePath("/cache/pip"))
+			run.AddMount(g.getWorkingDir(), llb.Local(flag.FlagBuildContext))
+			root = run.Root()
+		}
 	}
 
 	if len(g.PythonWheels) > 0 {
