@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -24,7 +24,6 @@ import (
 
 	"github.com/cockroachdb/errors"
 	"github.com/moby/buildkit/client/llb"
-	"github.com/moby/buildkit/client/llb/imagemetaresolver"
 	"github.com/sirupsen/logrus"
 
 	"github.com/tensorchord/envd/pkg/config"
@@ -150,7 +149,7 @@ func (g generalGraph) compileRun(root llb.State) llb.State {
 			sb.WriteString(c + "\n")
 		}
 
-		cmdStr := fmt.Sprintf("/usr/bin/bash -c '%s'", sb.String())
+		cmdStr := fmt.Sprintf("bash -c '%s'", sb.String())
 		logrus.WithField("command", cmdStr).Debug("compile run command")
 		// Mount the build context into the build process.
 		// TODO(gaocegege): Maybe we should make it readonly,
@@ -173,8 +172,15 @@ func (g generalGraph) compileCopy(root llb.State) llb.State {
 	result := root
 	// Compose the copy command.
 	for _, c := range g.Copy {
+		var from llb.State
+		if c.Image == "" {
+			from = llb.Local(flag.FlagBuildContext)
+		} else {
+			from = llb.Image(c.Image)
+		}
 		result = result.File(llb.Copy(
-			llb.Local(flag.FlagBuildContext), c.Source, c.Destination,
+			from, c.Source, c.Destination,
+			&llb.CopyInfo{CreateDestPath: true},
 			llb.WithUIDGID(g.uid, g.gid)))
 	}
 	return result
@@ -208,9 +214,23 @@ func (g generalGraph) compileSystemPackages(root llb.State) llb.State {
 }
 
 // nolint:unparam
-func (g *generalGraph) compileExtraSource(root llb.State) (llb.State, error) {
+func (g *generalGraph) compileExtraSource(root llb.State) llb.State {
 	if len(g.HTTP) == 0 {
-		return root, nil
+		return root
+	}
+	if g.DisableMergeOp {
+		for _, httpInfo := range g.HTTP {
+			src := llb.HTTP(
+				httpInfo.URL,
+				llb.Checksum(httpInfo.Checksum),
+				llb.Filename(httpInfo.Filename),
+				llb.Chown(g.uid, g.gid),
+			)
+			root = root.File(llb.Copy(
+				src, "/", g.getExtraSourceDir(), &llb.CopyInfo{CreateDestPath: true},
+			))
+		}
+		return root
 	}
 	inputs := []llb.State{}
 	for _, httpInfo := range g.HTTP {
@@ -225,55 +245,73 @@ func (g *generalGraph) compileExtraSource(root llb.State) (llb.State, error) {
 		))
 	}
 	inputs = append(inputs, root)
-	return llb.Merge(inputs, llb.WithCustomName("[internal] build source layers")), nil
+	return llb.Merge(inputs, llb.WithCustomName("[internal] build source layers"))
 }
 
 func (g *generalGraph) compileLanguage(root llb.State) (llb.State, error) {
+	langs := []llb.State{}
 	lang := root
 	var err error
-	switch g.Language.Name {
-	case "python":
-		lang, err = g.installPython(root)
-	case "r":
-		rSrc := g.compileRLang(root)
-		lang = g.installRLang(rSrc)
-	case "julia":
-		lang = g.installJulia(root)
+
+	if g.DisableMergeOp {
+		for _, language := range g.Languages {
+			switch language.Name {
+			case "python":
+				root, err = g.installPython(root)
+			case "r":
+				rSrc := g.compileRLang(root)
+				root = g.installRLang(rSrc)
+			case "julia":
+				root = g.installJulia(root)
+			}
+		}
+		return root, err
 	}
 
-	return lang, err
+	for _, language := range g.Languages {
+		switch language.Name {
+		case "python":
+			lang, err = g.installPython(root)
+		case "r":
+			rSrc := g.compileRLang(root)
+			lang = g.installRLang(rSrc)
+		case "julia":
+			lang = g.installJulia(root)
+		}
+		langs = append(langs, lang)
+	}
+	if len(langs) <= 1 {
+		return lang, err
+	}
+	for i, lang := range g.Languages {
+		langs[i] = llb.Diff(root, langs[i], llb.WithCustomNamef("[internal] build %s env", lang.Name))
+	}
+	return llb.Merge(append([]llb.State{root}, langs...),
+		llb.WithCustomName("[internal] merge all the language environments")), err
 }
 
 func (g *generalGraph) compileLanguagePackages(root llb.State) llb.State {
-	pack := root
-	switch g.Language.Name {
-	case "python":
-		index := g.compilePyPIIndex(root)
-		pypi := g.compilePyPIPackages(index)
-		if g.CondaConfig == nil {
-			pack = pypi
-		} else {
-			channel := g.compileCondaChannel(root)
-			conda := g.compileCondaPackages(channel)
-			pack = llb.Merge([]llb.State{
-				root,
-				llb.Diff(root, pypi, llb.WithCustomName("[internal] PyPI packages")),
-				llb.Diff(root, conda, llb.WithCustomName("[internal] conda packages")),
-			}, llb.WithCustomName("[internal] Python packages"))
+	// Use default python in the base image if install.python() is not specified.
+	g.compileJupyter()
+	index := g.compilePyPIIndex(root)
+	pack := g.compilePyPIPackages(index)
+	if g.CondaConfig != nil {
+		channel := g.compileCondaChannel(pack)
+		pack = g.compileCondaPackages(channel)
+	}
+
+	for _, language := range g.Languages {
+		switch language.Name {
+		case "r":
+			pack = g.installRPackages(pack)
+		case "julia":
+			pack = g.installJuliaPackages(pack)
 		}
-	case "r":
-		pack = g.installRPackages(root)
-	case "julia":
-		pack = g.installJuliaPackages(root)
 	}
 	return pack
 }
 
 func (g *generalGraph) compileDevPackages(root llb.State) llb.State {
-	for _, env := range types.BaseEnvironment {
-		root = root.AddEnv(env.Name, env.Value)
-	}
-
 	// apt packages
 	var sb strings.Builder
 	sb.WriteString("apt-get update && apt-get install -y apt-utils && ")
@@ -281,7 +319,6 @@ func (g *generalGraph) compileDevPackages(root llb.State) llb.State {
 	sb.WriteString(strings.Join(types.BaseAptPackage, " "))
 	sb.WriteString("&& rm -rf /var/lib/apt/lists/* ")
 	// shell prompt
-	sb.WriteString("&& curl --proto '=https' --tlsv1.2 -sSf https://starship.rs/install.sh | sh -s -- -y")
 	sb.WriteString("&& locale-gen en_US.UTF-8")
 
 	run := root.Run(llb.Shlexf(`bash -c "%s"`, sb.String()),
@@ -290,6 +327,14 @@ func (g *generalGraph) compileDevPackages(root llb.State) llb.State {
 	return run.Root()
 }
 
+func (g generalGraph) compileStarship(root llb.State) llb.State {
+	starship := root.File(llb.Copy(
+		llb.Image(types.EnvdStarshipImage), "/usr/local/bin/starship", "/usr/local/bin/starship",
+		&llb.CopyInfo{CreateDestPath: true}),
+		llb.WithCustomName(fmt.Sprintf("[internal] add envd-starship from %s", types.EnvdStarshipImage)))
+	return starship
+}
+
 func (g generalGraph) compileSSHD(root llb.State) llb.State {
 	sshd := root.File(llb.Copy(
 		llb.Image(types.EnvdSshdImage), "/usr/bin/envd-sshd", "/var/envd/bin/envd-sshd",
@@ -306,29 +351,73 @@ func (g *generalGraph) compileBaseImage() (llb.State, error) {
 
 	logger := logrus.WithFields(logrus.Fields{
 		"image":    g.Image,
-		"language": g.Language.Name,
+		"language": g.Languages,
 	})
-	if g.Language.Version != nil {
-		logger = logger.WithField("version", *g.Language.Version)
-	}
 	logger.Debug("compile base image")
 
 	// Fix https://github.com/tensorchord/envd/issues/1147.
 	// Fetch the image metadata from base image.
-	base := llb.Image(g.Image, llb.WithMetaResolver(imagemetaresolver.Default()))
-	envs, err := base.Env(context.Background())
+	base := llb.Image(g.Image)
+	// fetching the image config may take some time
+	config, err := ir.FetchImageConfig(context.Background(), g.Image, g.Platform)
+	if err != nil {
+		return llb.State{}, errors.Wrapf(err, "failed to get the image config, check if the image(%s) exists", g.Image)
+	}
 	if err != nil {
 		return llb.State{}, errors.Wrap(err, "failed to get the image metadata")
 	}
 
 	// Set the environment variables to RuntimeEnviron to keep it in the resulting image.
-	for _, e := range envs {
+	logger.Logger.Debugf("inherit envs from base image: %s", config.Env)
+	for _, e := range config.Env {
 		// in case the env value also contains `=`
 		kv := strings.SplitN(e, "=", 2)
 		g.RuntimeEnviron[kv[0]] = kv[1]
+		if kv[0] == "PATH" {
+			// deduplicate the PATH but keep the order as:
+			// 0. default Unix PATH
+			// 1. configured paths in the Starlark frontend `runtime.environ(extra_path=[...])`
+			// 2. paths in the base image
+			// 3. others added during the image building (Python paths, etc.)
+
+			// iterate over the original paths and add them to the map
+			pathMap := make(map[string]bool)
+			for _, path := range g.RuntimeEnvPaths {
+				pathMap[path] = true
+			}
+			// split the PATH into different paths
+			newPaths := strings.Split(kv[1], ":")
+			// iterate over the new paths
+			for _, path := range newPaths {
+				// check if the path is already in the map
+				if _, ok := pathMap[path]; !ok {
+					// if not, add the path to the map and slice
+					pathMap[path] = true
+					g.RuntimeEnvPaths = append(g.RuntimeEnvPaths, path)
+				}
+			}
+		}
+	}
+
+	// add necessary envs
+	for _, env := range types.BaseEnvironment {
+		base = base.AddEnv(env.Name, env.Value)
+	}
+	for k, v := range g.RuntimeEnviron {
+		base = base.AddEnv(k, v)
+	}
+
+	if !g.Dev {
+		if len(g.Entrypoint) == 0 {
+			g.Entrypoint = config.Entrypoint
+		}
+		g.User = config.User
+		g.WorkingDir = config.WorkingDir
+	} else {
+		// for dev mode, we will create an `envd` user
+		g.User = ""
+		g.WorkingDir = g.getWorkingDir()
 	}
-	// TODO: inherit the USER from base
-	g.User = ""
 	return base, nil
 }
 
