@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -15,6 +15,8 @@
 package v1
 
 import (
+	ocispecs "github.com/opencontainers/image-spec/specs-go/v1"
+
 	"github.com/tensorchord/envd/pkg/editor/vscode"
 	"github.com/tensorchord/envd/pkg/lang/ir"
 	"github.com/tensorchord/envd/pkg/progress/compileui"
@@ -28,15 +30,17 @@ type generalGraph struct {
 	uid int `default:"-1"`
 	gid int `default:"-1"`
 
-	ir.Language
-	Image string
-	User  string
+	Languages         []ir.Language
+	EnvdSyntaxVersion string
+	Image             string
+	User              string
 
 	Shell   string
 	Dev     bool
 	CUDA    *string
 	CUDNN   string
 	NumGPUs int
+	ShmSize int
 
 	UbuntuAPTSource    *string
 	CRANMirrorURL      *string
@@ -70,13 +74,24 @@ type generalGraph struct {
 	*ir.CondaConfig
 	*ir.RStudioServerConfig
 
-	Writer compileui.Writer
+	Writer compileui.Writer `json:"-"`
 	// EnvironmentName is the base name of the environment.
 	// It is the BaseDir(BuildContextDir)
 	// e.g. mnist, streamlit-mnist
 	EnvironmentName string
+	// EnvironmentPath is the full path of this environment.
+	EnvironmentPath string
+	// WorkingDir is the working directory of this environment.
+	// This only affect the `WorkingDir` in the image config.
+	WorkingDir string
+
+	// (v1) disable `merge` op for `moby` builder
+	// check https://github.com/tensorchord/envd/issues/1693
+	DisableMergeOp bool
 
 	ir.RuntimeGraph
+
+	Platform *ocispecs.Platform
 }
 
 const (
