@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -39,6 +39,9 @@ func (g *generalGraph) compileUserOwn(root llb.State) llb.State {
 	for _, env := range types.BaseEnvironment {
 		user = user.AddEnv(env.Name, env.Value)
 	}
+	for k, v := range g.RuntimeEnviron {
+		user = user.AddEnv(k, v)
+	}
 	user = user.AddEnv("PATH", strings.Join(g.RuntimeEnvPaths, ":"))
 	return user
 }
