@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -15,12 +15,16 @@
 package v1
 
 import (
+	"bufio"
 	"bytes"
 	"crypto/md5"
 	"encoding/gob"
 	"encoding/hex"
+	"encoding/json"
 	"fmt"
+	"os"
 	"os/user"
+	"path/filepath"
 	"regexp"
 	"runtime"
 	"strconv"
@@ -31,6 +35,7 @@ import (
 	"github.com/spf13/viper"
 
 	"github.com/tensorchord/envd/pkg/flag"
+	"github.com/tensorchord/envd/pkg/lang/ir"
 	"github.com/tensorchord/envd/pkg/util/fileutil"
 )
 
@@ -141,5 +146,80 @@ func GetCUDAImage(image string, cuda *string, cudnn string, dev bool) string {
 	}
 	imageTag := strings.Replace(image, ":", "", 1)
 
-	return fmt.Sprintf("docker.io/nvidia/cuda:%s-cudnn%s-%s-%s", *cuda, cudnn, target, imageTag)
+	newImage := fmt.Sprintf("docker.io/nvidia/cuda:%s-cudnn%s-%s-%s", *cuda, cudnn, target, imageTag)
+	if image != defaultImage {
+		logrus.Warnf("CUDA is only tested for %s, it might work with Ubuntu 18/22 base images. This feature will replace your base image to %s, make sure this meets your expectation.", defaultImage, newImage)
+	}
+	return newImage
+}
+
+func (g *generalGraph) Dump() (string, error) {
+	b, err := json.Marshal(g)
+	if err != nil {
+		return "", err
+	}
+	runtimeGraphCode := string(b)
+	return runtimeGraphCode, nil
+}
+
+func (g *generalGraph) Load(code []byte) error {
+	err := json.Unmarshal(code, g)
+	if err != nil {
+		return errors.Wrap(err, "failed to unmarshal")
+	}
+	return nil
+}
+
+func (g generalGraph) GeneralGraphFromLabel(label []byte) (ir.Graph, error) {
+	newg := generalGraph{}
+	err := newg.Load(label)
+	if err != nil {
+		return nil, err
+	}
+	return &newg, nil
+}
+
+// IsRequirementsFileSafeToCopyContent returns true and the dependencies in this file if the
+// requirements file is safe to copy. Otherwise, it returns false and empty dependencies.
+// check https://github.com/tensorchord/envd/issues/1629
+func (g generalGraph) IsRequirementsFileSafeToCopyContent() (dependencies []string, safe bool) {
+	if g.RequirementsFile == nil {
+		return
+	}
+	filePath := filepath.Join(g.EnvironmentPath, *g.RequirementsFile)
+	file, err := os.Open(filePath)
+	if err != nil {
+		logrus.WithError(err).Debugf("failed to open requirements file: %s", filePath)
+		return
+	}
+	defer file.Close()
+
+	forbidden := []string{
+		"-e",
+		"-r",
+		"-c",
+		"--find-links",
+	}
+
+	scanner := bufio.NewScanner(file)
+	for scanner.Scan() {
+		line := scanner.Text()
+		if strings.HasPrefix(line, "#") {
+			continue
+		}
+		for _, f := range forbidden {
+			if strings.Contains(line, f) {
+				logrus.Debugf("requirements file contains %s, which is not safe to copy", f)
+				return []string{}, false
+			}
+		}
+		exist, err := fileutil.FileExists(line)
+		// has a local file to install
+		if err == nil && exist {
+			logrus.Debugf("requirements file contains local file %s, which is not safe to copy", line)
+			return []string{}, false
+		}
+		dependencies = append(dependencies, line)
+	}
+	return dependencies, true
 }
