@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -55,7 +55,8 @@ func (c *dockerCollector) Watch(ctx context.Context, cid string) chan Metrics {
 		defer close(stats)
 		err := c.client.Stats(ctx, cid, stats, c.done)
 		if err != nil {
-			logrus.Error(err)
+			logrus.WithField("cid", cid).
+				WithError(err).Error("error occurred in dockerCollecter.Watch")
 		}
 		c.running = false
 	}()
