@@ -1,5 +1,5 @@
-// Copyright 2022 The envd Authors
-// Copyright 2022 The okteto remote Authors
+// Copyright 2023 The envd Authors
+// Copyright 2023 The okteto remote Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -18,7 +18,6 @@ package sshd
 import (
 	"fmt"
 	"io"
-	"io/ioutil"
 	"log"
 	"os"
 	"os/exec"
@@ -39,7 +38,7 @@ import (
 // LoadAuthorizedKeys loads path as an array.
 // It will return nil if path doesn't exist.
 func LoadAuthorizedKeys(path string) ([]ssh.PublicKey, error) {
-	authorizedKeysBytes, err := ioutil.ReadFile(path)
+	authorizedKeysBytes, err := os.ReadFile(path)
 	if err != nil {
 		if os.IsNotExist(err) {
 			return nil, nil
@@ -68,9 +67,11 @@ func LoadAuthorizedKeys(path string) ([]ssh.PublicKey, error) {
 
 // Server holds the ssh server configuration.
 type Server struct {
-	Port           int
-	Shell          string
+	Port  int
+	Shell string
+
 	AuthorizedKeys []ssh.PublicKey
+	Hostkey        ssh.Signer
 }
 
 // ListenAndServe starts the SSH server using port
@@ -82,6 +83,7 @@ func (srv *Server) ListenAndServe() error {
 	return server.ListenAndServe()
 }
 
+//nolint:unparam
 func (srv *Server) getServer() (*ssh.Server, error) {
 	forwardHandler := &ssh.ForwardedTCPHandler{}
 
@@ -116,6 +118,10 @@ func (srv *Server) getServer() (*ssh.Server, error) {
 		server.PasswordHandler = nil
 	}
 
+	if srv.Hostkey != nil {
+		server.AddHostKey(srv.Hostkey)
+	}
+
 	return server, nil
 }
 
@@ -175,7 +181,7 @@ func (srv *Server) connectionHandler(s ssh.Session) {
 
 		err := s.Exit(0)
 		if err != nil {
-			logger.Warningln("exit session with error:", err)
+			logger.WithError(err).Warnln("exit session with error")
 		}
 		return
 	}
@@ -188,7 +194,7 @@ func (srv *Server) connectionHandler(s ssh.Session) {
 
 	err := s.Exit(0)
 	if err != nil {
-		logger.Warningln("exit session with error:", err)
+		logger.WithError(err).Warnln("exit session with error")
 	}
 }
 
@@ -205,7 +211,7 @@ func handlePTY(logger *logrus.Entry, cmd *exec.Cmd, s ssh.Session, ptyReq ssh.Pt
 
 	go func() {
 		for win := range winCh {
-			setWinsize(f, win.Width, win.Height)
+			setWinSize(f, win.Width, win.Height)
 		}
 	}()
 
@@ -240,7 +246,7 @@ func handlePTY(logger *logrus.Entry, cmd *exec.Cmd, s ssh.Session, ptyReq ssh.Pt
 	return nil
 }
 
-func setWinsize(f *os.File, w, h int) {
+func setWinSize(f *os.File, w, h int) {
 	// TODO(gaocegege): Should we use syscall or docker resize?
 	// Refer to https://github.com/gliderlabs/ssh/blob/master/_examples/ssh-docker/docker.go#L99
 	_, _, err := syscall.Syscall(syscall.SYS_IOCTL, f.Fd(), uintptr(syscall.TIOCSWINSZ),
@@ -354,7 +360,7 @@ func (srv *Server) authorize(ctx ssh.Context, key ssh.PublicKey) bool {
 }
 
 func sftpHandler(sess ssh.Session) {
-	debugStream := ioutil.Discard
+	debugStream := io.Discard
 	serverOptions := []sftp.ServerOption{
 		sftp.WithDebug(debugStream),
 	}
