@@ -1,5 +1,5 @@
-// Copyright 2022 The envd Authors
-// Copyright 2022 The Okteto Authors
+// Copyright 2023 The envd Authors
+// Copyright 2023 The Okteto Authors
 // based on https://github.com/havoc-io/sshconfig
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
@@ -232,7 +232,8 @@ func (config *sshConfig) writeTo(w io.Writer) error {
 func (config *sshConfig) writeToFilepath(p string) error {
 	sshDir := filepath.Dir(p)
 	if err := os.MkdirAll(sshDir, 0700); err != nil {
-		logrus.Infof("failed to create SSH directory %s: %s", sshDir, err)
+		logrus.WithError(err).
+			Infof("failed to create SSH directory %s", sshDir)
 	}
 
 	stat, err := os.Stat(p)
@@ -301,7 +302,7 @@ func (h *host) getParam(keyword string) *param {
 	return nil
 }
 
-func buildHostname(name string) string {
+func BuildHostname(name string) string {
 	return fmt.Sprintf("%s.envd", name)
 }
 
@@ -386,7 +387,7 @@ func GetPort(name string) (int, error) {
 		return 0, err
 	}
 
-	hostname := buildHostname(name)
+	hostname := BuildHostname(name)
 	i, found := findHost(cfg, hostname)
 	if !found {
 		return 0, errors.Newf("development container not found")
@@ -477,7 +478,7 @@ func save(cfg *sshConfig, path string) error {
 func getSSHConfigPath() string {
 	dirname, err := os.UserHomeDir()
 	if err != nil {
-		logrus.Fatal(err)
+		logrus.WithError(err).Fatal()
 	}
 	return filepath.Join(dirname, ".ssh", "config")
 }
