@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -27,7 +27,7 @@ var _ = Describe("ssh config", func() {
 			port := 8888
 			keyPath := "key"
 			eo := EntryOptions{
-				Name:               buildHostname(env),
+				Name:               BuildHostname(env),
 				IFace:              iface,
 				Port:               port,
 				PrivateKeyPath:     keyPath,
