@@ -1,6 +1,6 @@
-// Copyright 2022 The envd Authors
-// Copyright 2022 The okteto Authors
-// Copyright 2022 stefanprodan
+// Copyright 2023 The envd Authors
+// Copyright 2023 The okteto Authors
+// Copyright 2023 stefanprodan
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -40,6 +40,7 @@ type Client interface {
 	Attach() error
 	ExecWithOutput(cmd string) ([]byte, error)
 	LocalForward(localAddress, targetAddress string) error
+	RemoteForward(localAddress, targetAddress string) error
 	Close() error
 }
 
@@ -84,13 +85,14 @@ type generalClient struct {
 }
 
 func NewClient(opt Options) (Client, error) {
-	logrus.WithFields(logrus.Fields{
+	logger := logrus.WithFields(logrus.Fields{
 		"user":             opt.User,
 		"port":             opt.Port,
 		"server":           opt.Server,
 		"agent-forwarding": opt.AgentForwarding,
 		"auth":             opt.Auth,
-	}).Debug("ssh to the environment")
+	})
+	logger.Debug("ssh to the environment")
 
 	config := &ssh.ClientConfig{
 		User: opt.User,
@@ -145,7 +147,7 @@ func NewClient(opt Options) (Client, error) {
 				return nil, errors.Wrap(err, "forwarding agent to client failed")
 			}
 		} else {
-			logrus.Warn("SSH Agent Forwarding is disabled. This will have no impact on your normal use if you do not use the ssh key on the host.")
+			logger.Warn("SSH Agent Forwarding is disabled. This will have no impact on your normal use if you do not use the ssh key on the host.")
 		}
 	}
 
@@ -192,6 +194,14 @@ func (c generalClient) Attach() error {
 		}
 	}
 
+	logger := logrus.WithFields(logrus.Fields{
+		"user":             c.opt.User,
+		"port":             c.opt.Port,
+		"server":           c.opt.Server,
+		"agent-forwarding": c.opt.AgentForwarding,
+		"auth":             c.opt.Auth,
+	})
+
 	modes := ssh.TerminalModes{
 		ssh.ECHO:          0,      // Disable echoing
 		ssh.ECHOCTL:       0,      // Don't print control chars
@@ -205,15 +215,15 @@ func (c generalClient) Attach() error {
 	var ok bool
 	if termFD, ok = isTerminal(os.Stdin); ok {
 		width, height, err = term.GetSize(int(os.Stdout.Fd()))
-		logrus.Debugf("terminal width %d height %d", width, height)
+		logger.Debugf("terminal width %d height %d", width, height)
 		if err != nil {
-			logrus.Debugf("request for terminal size failed: %s", err)
+			logger.WithError(err).Debug("request for terminal size failed")
 		}
 	}
 
 	state, err := term.MakeRaw(termFD)
 	if err != nil {
-		logrus.Debugf("request for raw terminal failed: %s", err)
+		logger.WithError(err).Debug("request for raw terminal failed")
 	}
 
 	defer func() {
@@ -222,10 +232,10 @@ func (c generalClient) Attach() error {
 		}
 
 		if err := term.Restore(termFD, state); err != nil {
-			logrus.Debugf("failed to restore terminal: %s", err)
+			logger.WithError(err).Debugf("failed to restore terminal")
 		}
 
-		logrus.Debugf("terminal restored")
+		logger.Debugf("terminal restored")
 	}()
 
 	if err := session.RequestPty("xterm-256color", height, width, modes); err != nil {
@@ -236,12 +246,12 @@ func (c generalClient) Attach() error {
 	session.Stderr = os.Stderr
 	session.Stdin = os.Stdin
 
-	logrus.Debug("starting shell")
+	logger.Debug("starting shell")
 	err = session.Shell()
 	if err != nil {
 		return errors.Wrap(err, "starting shell failed")
 	}
-	logrus.Debug("waiting for shell to exit")
+	logger.Debug("waiting for shell to exit")
 	if err = session.Wait(); err != nil {
 		var ee *ssh.ExitError
 		if ok := errors.As(err, &ee); ok {
@@ -249,18 +259,18 @@ func (c generalClient) Attach() error {
 			case 130:
 				return nil
 			case 137:
-				logrus.Warn(`Insufficient memory.`)
+				logger.Warn(`Insufficient memory.`)
 			}
 		}
 		var emr *ssh.ExitMissingError
 		if ok := errors.As(err, &emr); ok {
-			logrus.Debugf("exit status missing: %s", emr)
+			logger.WithError(emr).Debug("exit status missing")
 			return nil
 		}
 		return errors.Wrap(err, "waiting for session failed")
 	}
 
-	logrus.Debug("shell exited")
+	logger.Debug("shell exited")
 	return nil
 }
 
@@ -270,7 +280,9 @@ func (c generalClient) LocalForward(localAddress, targetAddress string) error {
 		return errors.Wrap(err, "net.Listen failed")
 	}
 
-	logrus.Debug("begin to forward " + localAddress + " to " + targetAddress)
+	logger := logrus.WithField("type", "local")
+
+	logger.Debugf("begin to forward %s to %s", localAddress, targetAddress)
 	for {
 		localCon, err := localListener.Accept()
 		if err != nil {
@@ -286,7 +298,7 @@ func (c generalClient) LocalForward(localAddress, targetAddress string) error {
 		go func() {
 			_, err = io.Copy(sshConn, localCon)
 			if err != nil {
-				logrus.Debugf("io.Copy failed: %v", err)
+				logger.WithError(err).Debug("io.Copy failed")
 			}
 		}()
 
@@ -294,7 +306,45 @@ func (c generalClient) LocalForward(localAddress, targetAddress string) error {
 		go func() {
 			_, err = io.Copy(localCon, sshConn)
 			if err != nil {
-				logrus.Debugf("io.Copy failed: %v", err)
+				logger.WithError(err).Debug("io.Copy failed")
+			}
+		}()
+	}
+}
+
+func (c generalClient) RemoteForward(remoteAddress, targetAddress string) error {
+	sshListener, err := c.cli.Listen("tcp", remoteAddress)
+	if err != nil {
+		return errors.Wrap(err, "cli.Listen failed")
+	}
+
+	logger := logrus.WithField("type", "remote")
+
+	logger.Debugf("begin to forward %s to %s", remoteAddress, targetAddress)
+	for {
+		sshCon, err := sshListener.Accept()
+		if err != nil {
+			return errors.Wrap(err, "listen.Accept failed")
+		}
+
+		targetCon, err := net.Dial("tcp", targetAddress)
+		if err != nil {
+			return errors.Wrap(err, "net.Dial failed")
+		}
+
+		// Copy sshCon.Reader to targetCon.Writer
+		go func() {
+			_, err = io.Copy(targetCon, sshCon)
+			if err != nil {
+				logger.WithError(err).Debug("io.Copy failed")
+			}
+		}()
+
+		// Copy targetCon.Reader to sshCon.Writer
+		go func() {
+			_, err = io.Copy(sshCon, targetCon)
+			if err != nil {
+				logger.WithError(err).Debug("io.Copy failed")
 			}
 		}()
 	}
@@ -357,23 +407,20 @@ func parsePemBlock(block *pem.Block) (interface{}, error) {
 		key, err := x509.ParsePKCS1PrivateKey(block.Bytes)
 		if err != nil {
 			return nil, errors.Newf("Parsing PKCS private key failed %w", err)
-		} else {
-			return key, nil
 		}
+		return key, nil
 	case "EC PRIVATE KEY":
 		key, err := x509.ParseECPrivateKey(block.Bytes)
 		if err != nil {
 			return nil, errors.Newf("Parsing EC private key failed %w", err)
-		} else {
-			return key, nil
 		}
+		return key, nil
 	case "DSA PRIVATE KEY":
 		key, err := ssh.ParseDSAPrivateKey(block.Bytes)
 		if err != nil {
 			return nil, errors.Newf("Parsing DSA private key failed %w", err)
-		} else {
-			return key, nil
 		}
+		return key, nil
 	default:
 		return nil, errors.Newf("Parsing private key failed, unsupported key type %q", block.Type)
 	}
