@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -33,9 +33,10 @@ const (
 	DefaultCondaPath  = "/opt/conda/envs/envd/bin:/opt/conda/bin:/home/envd/.local/bin"
 	DefaultJuliaPath  = "/usr/local/julia/bin"
 	// image
-	PythonBaseImage = "ubuntu:20.04"
+	PythonBaseImage   = "ubuntu:20.04"
+	EnvdStarshipImage = "tensorchord/starship:v0.0.1"
 	// supervisor
-	HorustImage      = "tensorchord/horust:v0.2.1"
+	HorustImage      = "tensorchord/horust:v0.2.3"
 	HorustServiceDir = "/etc/horust/services"
 	HorustLogDir     = "/var/log/horust"
 	// env
@@ -121,6 +122,7 @@ type Context struct {
 type BuilderType string
 
 const (
+	BuilderTypeMoby             BuilderType = "moby-worker"
 	BuilderTypeDocker           BuilderType = "docker-container"
 	BuilderTypeNerdctl          BuilderType = "nerdctl-container"
 	BuilderTypeKubernetes       BuilderType = "kube-pod"
