@@ -1,4 +1,4 @@
-// Copyright 2022 The envd Authors
+// Copyright 2023 The envd Authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -32,13 +32,13 @@ func GetFreePort() (int, error) {
 
 // GetHost get the IP address from the address.
 func GetHost(addr string) (string, error) {
-	if u, err := url.Parse(addr); err != nil {
+	u, err := url.Parse(addr)
+	if err != nil {
 		return "", err
-	} else {
-		h := u.Hostname()
-		if h == "" {
-			return "", fmt.Errorf("failed to get the hostname from %s", addr)
-		}
-		return h, nil
 	}
+	h := u.Hostname()
+	if h == "" {
+		return "", fmt.Errorf("failed to get the hostname from %s", addr)
+	}
+	return h, nil
 }
